"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *
import enum


class QFileDevice(QIODevice):
    """
    https://doc.qt.io/qt-6/qfiledevice.html

    **Detailed Description**

    QFileDevice is the base class for I/O devices that can read and write text
    and binary files and **resources** . **QFile**  offers the main
    functionality, QFileDevice serves as a base class for sharing functionality
    with other file devices such as **QTemporaryFile** , by providing all the
    operations that can be done on files that have been opened by **QFile**  or
    **QTemporaryFile** .

    **See also** **QFile**  and **QTemporaryFile** .
    """

    class MemoryMapFlag(enum.Flag):
        NoOptions: QFileDevice = ...
        MapPrivateOption: QFileDevice = ...

    class FileTime(enum.Enum):
        FileAccessTime: QFileDevice = ...
        FileBirthTime: QFileDevice = ...
        FileMetadataChangeTime: QFileDevice = ...
        FileModificationTime: QFileDevice = ...

    class FileHandleFlag(enum.Flag):
        AutoCloseHandle: QFileDevice = ...
        DontCloseHandle: QFileDevice = ...

    class Permission(enum.Flag):
        ReadOwner: QFileDevice = ...
        WriteOwner: QFileDevice = ...
        ExeOwner: QFileDevice = ...
        ReadUser: QFileDevice = ...
        WriteUser: QFileDevice = ...
        ExeUser: QFileDevice = ...
        ReadGroup: QFileDevice = ...
        WriteGroup: QFileDevice = ...
        ExeGroup: QFileDevice = ...
        ReadOther: QFileDevice = ...
        WriteOther: QFileDevice = ...
        ExeOther: QFileDevice = ...

    class FileError(enum.Enum):
        NoError: QFileDevice = ...
        ReadError: QFileDevice = ...
        WriteError: QFileDevice = ...
        FatalError: QFileDevice = ...
        ResourceError: QFileDevice = ...
        OpenError: QFileDevice = ...
        AbortError: QFileDevice = ...
        TimeOutError: QFileDevice = ...
        UnspecifiedError: QFileDevice = ...
        RemoveError: QFileDevice = ...
        RenameError: QFileDevice = ...
        PositionError: QFileDevice = ...
        ResizeError: QFileDevice = ...
        PermissionsError: QFileDevice = ...
        CopyError: QFileDevice = ...

    def setFileTime(
        self,
        newDate: typing.Union[QDateTime, datetime.datetime],
        fileTime: "QFileDevice.FileTime",
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#setFileTime

        **[since 5.10] bool QFileDevice::setFileTime(const QDateTime & newDate ,
        QFileDevice::FileTime fileTime )**

        Sets the file time specified by **fileTime** to **newDate** , returning
        true if successful; otherwise returns false.

        **Note:** The file must be open to use this function.

        This function was introduced in Qt 5.10.

        **See also** **fileTime** () and **FileTime** .
        """
        ...

    def fileTime(self, time: "QFileDevice.FileTime") -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#fileTime

        **[since 5.10] QDateTime QFileDevice::fileTime(QFileDevice::FileTime
        time ) const**

        Returns the file time specified by **time**. If the time cannot be
        determined return QDateTime() (an invalid date time).

        This function was introduced in Qt 5.10.

        **See also** **setFileTime** (), **FileTime** , and
        **QDateTime::isValid** ().
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#writeData

        **[override virtual protected] qint64 QFileDevice::writeData(const char
        * data , qint64 len )**

        Reimplements: **QIODevice::writeData** (const char *data, qint64
        maxSize).
        """
        ...

    def readLineData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#readLineData

        **[override virtual protected] qint64 QFileDevice::readLineData(char *
        data , qint64 maxlen )**

        Reimplements: **QIODevice::readLineData** (char *data, qint64 maxSize).
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#readData

        **[override virtual protected] qint64 QFileDevice::readData(char * data
        , qint64 len )**

        Reimplements: **QIODevice::readData** (char *data, qint64 maxSize).
        """
        ...

    def unmap(self, address: PyQt6.sip.voidptr) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#unmap

        **bool QFileDevice::unmap(uchar * address )**

        Unmaps the memory **address**.

        Returns `true` if the unmap succeeds; false otherwise.

        **See also** **map** ().
        """
        ...

    def map(
        self, offset: int, size: int, flags: "QFileDevice.MemoryMapFlag" = ...
    ) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#map

        **uchar *QFileDevice::map(qint64 offset , qint64 size ,
        QFileDevice::MemoryMapFlags flags = NoOptions)**

        Maps **size** bytes of the file into memory starting at **offset**. A
        file should be open for a map to succeed but the file does not need to
        stay open after the memory has been mapped. When the **QFile**  is
        destroyed or a new file is opened with this object, any maps that have
        not been unmapped will automatically be unmapped.

        The mapping will have the same open mode as the file (read and/or
        write), except when using **MapPrivateOption** , in which case it is
        always possible to write to the mapped memory.

        Any mapping options can be passed through **flags**.

        Returns a pointer to the memory or `nullptr` if there is an error.

        **See also** **unmap** ().
        """
        ...

    def setPermissions(self, permissionSpec: "QFileDevice.Permission") -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#setPermissions

        **[virtual] bool QFileDevice::setPermissions(QFileDevice::Permissions
        permissions )**

        Sets the permissions for the file to the **permissions** specified.
        Returns `true` if successful, or `false` if the permissions cannot be
        modified.

        **Warning:** This function does not manipulate ACLs, which may limit its
        effectiveness.

        **See also** **permissions** ().
        """
        ...

    def permissions(self) -> "QFileDevice.Permission":
        """
        https://doc.qt.io/qt-6/qfiledevice.html#permissions

        **[virtual] QFileDevice::Permissions QFileDevice::permissions() const**

        Returns the complete OR-ed together combination of QFile::Permission for
        the file.

        **See also** **setPermissions** ().
        """
        ...

    def resize(self, sz: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#resize

        **[virtual] bool QFileDevice::resize(qint64 sz )**

        Sets the file size (in bytes) **sz**. Returns `true` if the resize
        succeeds; false otherwise. If **sz** is larger than the file currently
        is, the new bytes will be set to 0; if **sz** is smaller, the file is
        simply truncated.

        **Warning:** This function can fail if the file doesn't exist.

        **See also** **size** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#size

        **[override virtual] qint64 QFileDevice::size() const**

        Reimplements: **QIODevice::size() const** .

        Returns the size of the file.

        For regular empty files on Unix (e.g. those in `/proc`), this function
        returns 0; the contents of such a file are generated on demand in
        response to you calling **read** ().
        """
        ...

    def flush(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#flush

        **bool QFileDevice::flush()**

        Flushes any buffered data to the file. Returns `true` if successful;
        otherwise returns `false`.
        """
        ...

    def atEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#atEnd

        **[override virtual] bool QFileDevice::atEnd() const**

        Reimplements: **QIODevice::atEnd() const** .

        Returns `true` if the end of the file has been reached; otherwise
        returns false.

        For regular empty files on Unix (e.g. those in `/proc`), this function
        returns `true`, since the file system reports that the size of such a
        file is 0. Therefore, you should not depend on atEnd() when reading data
        from such a file, but rather call **read** () until no more data can be
        read.
        """
        ...

    def seek(self, offset: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#seek

        **[override virtual] bool QFileDevice::seek(qint64 pos )**

        Reimplements: **QIODevice::seek** (qint64 pos).

        For random-access devices, this function sets the current position to
        **pos** , returning true on success, or false if an error occurred. For
        sequential devices, the default behavior is to do nothing and return
        false.

        Seeking beyond the end of a file: If the position is beyond the end of a
        file, then seek() will not immediately extend the file. If a write is
        performed at this position, then the file will be extended. The content
        of the file between the previous end of file and the newly written data
        is UNDEFINED and varies between platforms and file systems.
        """
        ...

    def pos(self) -> int:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#pos

        **[override virtual] qint64 QFileDevice::pos() const**

        Reimplements: **QIODevice::pos() const** .
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#fileName

        **[virtual] QString QFileDevice::fileName() const**

        Returns the name of the file. The default implementation in
        **QFileDevice**  returns a null string.
        """
        ...

    def handle(self) -> int:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#handle

        **int QFileDevice::handle() const**

        Returns the file handle of the file.

        This is a small positive integer, suitable for use with C library
        functions such as `fdopen()` and `fcntl()`. On systems that use file
        descriptors for sockets (i.e. Unix systems, but not Windows) the handle
        can be used with **QSocketNotifier**  as well.

        If the file is not open, or there is an error, handle() returns -1.

        **See also** **QSocketNotifier** .
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#isSequential

        **[override virtual] bool QFileDevice::isSequential() const**

        Reimplements: **QIODevice::isSequential() const** .

        Returns `true` if the file can only be manipulated sequentially;
        otherwise returns `false`.

        Most files support random-access, but some special files may not.

        **See also** **QIODevice::isSequential** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#close

        **[override virtual] void QFileDevice::close()**

        Reimplements: **QIODevice::close** ().

        Calls **QFileDevice::flush** () and closes the file. Errors from flush
        are ignored.

        **See also** **QIODevice::close** ().
        """
        ...

    def unsetError(self) -> None:
        """
        https://doc.qt.io/qt-6/qfiledevice.html#unsetError

        **void QFileDevice::unsetError()**

        Sets the file's error to **QFileDevice::NoError** .

        **See also** **error** ().
        """
        ...

    def error(self) -> "QFileDevice.FileError":
        """
        https://doc.qt.io/qt-6/qfiledevice.html#error

        **QFileDevice::FileError QFileDevice::error() const**

        Returns the file error status.

        The I/O device status returns an error code. For example, if **open** ()
        returns `false`, or a read/write operation returns -1, this function can
        be called to find out the reason why the operation failed.

        **See also** **unsetError** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QWhatsThis(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwhatsthis.html

    **Detailed Description**

    "What's This?" help is part of an application's online help system, and
    provides users with information about the functionality and usage of a
    particular widget. "What's This?" help texts are typically longer and more
    detailed than **tooltips** , but generally provide less information than
    that supplied by separate help windows.

    QWhatsThis provides a single window with an explanatory text that pops up
    when the user asks "What's This?". The default way for users to ask the
    question is to move the focus to the relevant widget and press Shift+F1. The
    help text appears immediately; it goes away as soon as the user does
    something else. (Note that if there is a shortcut for Shift+F1, this
    mechanism will not work.) Some dialogs provide a "?" button that users can
    click to enter "What's This?" mode; they then click the relevant widget to
    pop up the "What's This?" window. It is also possible to provide a a menu
    option or toolbar button to switch into "What's This?" mode.

    To add "What's This?" text to a widget or an action, you simply call
    **QWidget::setWhatsThis** () or **QAction::setWhatsThis** ().

    The text can be either rich text or plain text. If you specify a rich text
    formatted string, it will be rendered using the default stylesheet, making
    it possible to embed images in the displayed text. To be as fast as
    possible, the default stylesheet uses a simple method to determine whether
    the text can be rendered as plain text. See **Qt::mightBeRichText** () for
    details.

    newAct = new **QAction** (tr("&New"), this);
    newAct->setShortcut(tr("Ctrl+N"));
            newAct->setStatusTip(tr("Create a
    new file"));
            newAct->setWhatsThis(tr("Click this option to create a
    new file."));

    An alternative way to enter "What's This?" mode is to call **createAction**
    (), and add the returned **QAction**  to either a menu or a tool bar. By
    invoking this context help action (in the picture below, the button with the
    arrow and question mark icon) the user switches into "What's This?" mode. If
    they now click on a widget the appropriate help text is shown. The mode is
    left when help is given or when the user presses Esc.

    ![](images/whatsthis.png)

    You can enter "What's This?" mode programmatically with
    **enterWhatsThisMode** (), check the mode with **inWhatsThisMode** (), and
    return to normal mode with **leaveWhatsThisMode** ().

    If you want to control the "What's This?" behavior of a widget manually see
    **Qt::WA_CustomWhatsThis** .

    It is also possible to show different help texts for different regions of a
    widget, by using a **QHelpEvent**  of type **QEvent::WhatsThis** . Intercept
    the help event in your widget's **QWidget::event** () function and call
    **QWhatsThis::showText** () with the text you want to display for the
    position specified in **QHelpEvent::pos** (). If the text is rich text and
    the user clicks on a link, the widget also receives a
    **QWhatsThisClickedEvent**  with the link's reference as
    **QWhatsThisClickedEvent::href** (). If a **QWhatsThisClickedEvent**  is
    handled (i.e. **QWidget::event** () returns true), the help window remains
    visible. Call **QWhatsThis::hideText** () to hide it explicitly.

    **See also** **QToolTip** .
    """

    def __init__(self, a0: "QWhatsThis") -> None:
        ...

    @staticmethod
    def createAction(parent: typing.Optional[QtCore.QObject] = ...) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#createAction

        **[static] QAction *QWhatsThis::createAction(QObject * parent =
        nullptr)**

        Returns a ready-made **QAction** , used to invoke "What's This?" context
        help, with the given **parent**.

        The returned **QAction**  provides a convenient way to let users enter
        "What's This?" mode.
        """
        ...

    @staticmethod
    def hideText() -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#hideText

        **[static] void QWhatsThis::hideText()**

        If a "What's This?" window is showing, this destroys it.

        **See also** **showText** ().
        """
        ...

    @staticmethod
    def showText(
        pos: QtCore.QPoint, text: str, widget: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#showText

        **[static] void QWhatsThis::showText(const QPoint & pos , const QString
        & text , QWidget * w = nullptr)**

        Shows **text** as a "What's This?" window, at global position **pos**.
        The optional widget argument, **w** , is used to determine the
        appropriate screen on multi-head systems.

        **See also** **hideText** ().
        """
        ...

    @staticmethod
    def leaveWhatsThisMode() -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#leaveWhatsThisMode

        **[static] void QWhatsThis::leaveWhatsThisMode()**

        If the user interface is in "What's This?" mode, this function switches
        back to normal mode; otherwise it does nothing.

        When leaving "What's This?" mode, a **QEvent**  of type
        Qt::LeaveWhatsThisMode is sent to all toplevel widgets.

        **See also** **enterWhatsThisMode** () and **inWhatsThisMode** ().
        """
        ...

    @staticmethod
    def inWhatsThisMode() -> bool:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#inWhatsThisMode

        **[static] bool QWhatsThis::inWhatsThisMode()**

        Returns `true` if the user interface is in "What's This?" mode;
        otherwise returns `false`.

        **See also** **enterWhatsThisMode** ().
        """
        ...

    @staticmethod
    def enterWhatsThisMode() -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthis.html#enterWhatsThisMode

        **[static] void QWhatsThis::enterWhatsThisMode()**

        This function switches the user interface into "What's This?" mode. The
        user interface can be switched back into normal mode by the user (e.g.
        by them clicking or pressing Esc), or programmatically by calling
        **leaveWhatsThisMode** ().

        When entering "What's This?" mode, a **QEvent**  of type
        Qt::EnterWhatsThisMode is sent to all toplevel widgets.

        **See also** **inWhatsThisMode** () and **leaveWhatsThisMode** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtQuick3D import *
import enum


class QQuick3DTextureData(QQuick3DObject):
    """
    https://doc.qt.io/qt-6/qquick3dtexturedata.html

    **Detailed Description**

    The QQuick3DTextureData class can be used to specify custom texture data for
    a **Texture**  in a Qt Quick 3D scene.

    While not strictly required, the typical usage is to inherit from this
    class. The subclass is then exposed to QML by registering it to the type
    system. The **textureData**  property of a **Texture**  can then be set to
    reference an instance of the registered type.

    Example implementation:

    class CustomTextureData : public QQuick3DTextureData
        {
            Q_OBJECT
    ... properties ...

        public:
            CustomTextureData() {
    regenerateTextureData(); }

            void setProperty(...)
            {
    // Change relevant internal data.
                // ...

                //
    Update the texture data
                regenerateTextureData();
    // Finally, trigger an update. This is relevant in case nothing else
    // is changed in the scene; this way we make sure a new frame will
    // be rendered
                update();
            }
        private:
            void
    regenerateTextureData()
            {
                **QByteArray**  textureData;
    textureData = generateTextureData();
    setTextureData(textureData);
                setSize(**QSize** (256, 256));
    setFormat(QQuick3DTextureData::Format::RGBA8)
    setHasTransparency(true);
            }
        };

    This class can then be registered as a QML type and used with **Texture** .

    In Qt 5 type registration happened with **qmlRegisterType** :

    qmlRegisterType<MyCustomTextureData>("Example", 1, 0,
    "MyCustomTextureData");

    In Qt 6 the default approach is to use automatic registration with the help
    of the build system. Instead of calling **qmlRegisterType** , the `.pro`
    file can now contain:

    CONFIG += qmltypes
        QML_IMPORT_NAME = Example
    QML_IMPORT_MAJOR_VERSION = 1

    With CMake, automatic registration is the default behavior, so no special
    settings are needed beyond basic QML module setup:

    qt_add_qml_module(application
            URI Example
            VERSION 1.0
        )

    The class implementation should add **QML_NAMED_ELEMENT** :

    class CustomTextureData : public QQuick3DTextureData
        {
            Q_OBJECT
    QML_NAMED_ELEMENT(MyCustomTextureData)
            ...
        };

    The QML code can then use the custom type:

    import Example 1.0

        Model {
            source: "#Cube"
    materials: [
                DefaultMaterial {
                    diffuseMap:
    diffuseMapCustomTexture
                }
            ]
            Texture {
    id: diffuseMapCustomTexture
                textureData: MyCustomTextureData { }
    }
        }
    """

    class Format(enum.Enum):
        None_: QQuick3DTextureData = ...
        RGBA8: QQuick3DTextureData = ...
        RGBA16F: QQuick3DTextureData = ...
        RGBA32F: QQuick3DTextureData = ...
        RGBE8: QQuick3DTextureData = ...
        R8: QQuick3DTextureData = ...
        R16: QQuick3DTextureData = ...
        R16F: QQuick3DTextureData = ...
        R32F: QQuick3DTextureData = ...
        BC1: QQuick3DTextureData = ...
        BC2: QQuick3DTextureData = ...
        BC3: QQuick3DTextureData = ...
        BC4: QQuick3DTextureData = ...
        BC5: QQuick3DTextureData = ...
        BC6H: QQuick3DTextureData = ...
        BC7: QQuick3DTextureData = ...
        DXT1_RGBA: QQuick3DTextureData = ...
        DXT1_RGB: QQuick3DTextureData = ...
        DXT3_RGBA: QQuick3DTextureData = ...
        DXT5_RGBA: QQuick3DTextureData = ...
        ETC2_RGB8: QQuick3DTextureData = ...
        ETC2_RGB8A1: QQuick3DTextureData = ...
        ETC2_RGBA8: QQuick3DTextureData = ...
        ASTC_4x4: QQuick3DTextureData = ...
        ASTC_5x4: QQuick3DTextureData = ...
        ASTC_5x5: QQuick3DTextureData = ...
        ASTC_6x5: QQuick3DTextureData = ...
        ASTC_6x6: QQuick3DTextureData = ...
        ASTC_8x5: QQuick3DTextureData = ...
        ASTC_8x6: QQuick3DTextureData = ...
        ASTC_8x8: QQuick3DTextureData = ...
        ASTC_10x5: QQuick3DTextureData = ...
        ASTC_10x6: QQuick3DTextureData = ...
        ASTC_10x8: QQuick3DTextureData = ...
        ASTC_10x10: QQuick3DTextureData = ...
        ASTC_12x10: QQuick3DTextureData = ...
        ASTC_12x12: QQuick3DTextureData = ...

    def __init__(self, parent: typing.Optional[QQuick3DObject] = ...) -> None:
        ...

    def setHasTransparency(self, hasTransparency: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#setHasTransparency

        **void QQuick3DTextureData::setHasTransparency(bool hasTransparency )**

        Set **hasTransparency** to true if the texture data has an active alpha
        channel with non-opaque values.

        This is used as an optimization by the engine so that for formats that
        do support an alpha channel do not need to have each value checked for
        non-opaque values.

        **See also** **hasTransparency** ().
        """
        ...

    def hasTransparency(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#hasTransparency

        **bool QQuick3DTextureData::hasTransparency() const**

        Returns `true` if the texture data has transparency.

        The default value is `false`.

        **See also** **setHasTransparency** ().
        """
        ...

    def setFormat(self, format: "QQuick3DTextureData.Format") -> None:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#setFormat

        **void QQuick3DTextureData::setFormat(QQuick3DTextureData::Format format
        )**

        Sets the **format** of the texture data.

        The default format is /c RGBA8

        **See also** **format** ().
        """
        ...

    def format(self) -> "QQuick3DTextureData.Format":
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#format

        **QQuick3DTextureData::Format QQuick3DTextureData::format() const**

        Returns the format of the texture data.

        **See also** **setFormat** ().
        """
        ...

    def setSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#setSize

        **void QQuick3DTextureData::setSize(const QSize & size )**

        Sets the **size** of the texture data in pixels.

        **See also** **size** ().
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#size

        **QSize QQuick3DTextureData::size() const**

        Returns the size of the texture data in pixels.

        **See also** **setSize** ().
        """
        ...

    def setTextureData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#setTextureData

        **void QQuick3DTextureData::setTextureData(const QByteArray & data )**

        Sets the texture data. The contents of **data** must respect the
        **size**  and **format**  properties as the backend will try and upload
        and use the data as if it were a texture of size and format, and if
        there is any deviation the result will be somewhere between incorrect
        rendering of the texture, or potentially a crash.

        **See also** **textureData** ().
        """
        ...

    def textureData(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qquick3dtexturedata.html#textureData

        **const QByteArray QQuick3DTextureData::textureData() const**

        Returns the current texture data defined by this item.

        **See also** **setTextureData** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QFileOpenEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qfileopenevent.html

    **Detailed Description**

    File open events will be sent to the **QApplication::instance** () when the
    operating system requests that a file or URL should be opened. This is a
    high-level event that can be caused by different user actions depending on
    the user's desktop environment; for example, double clicking on an file icon
    in the Finder on macOS.

    This event is only used to notify the application of a request. It may be
    safely ignored.

    **Note:** This class is currently supported for macOS only.

    **macOS Example**

    In order to trigger the event on macOS, the application must be configured
    to let the OS know what kind of file(s) it should react on.

    For example, the following `Info.plist` file declares that the application
    can act as a viewer for files with a PNG extension:

    <?xml version="1.0" encoding="UTF-8"?>
        <!DOCTYPE plist PUBLIC
    "-//Apple//DTD PLIST 1.0//EN"
    "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
        <plist version="1.0">
    <dict>
            <key>CFBundleDocumentTypes</key>
            <array>
    <dict>
                    <key>CFBundleTypeExtensions</key>
    <array>
                        <string>png</string>
                    </array>
    <key>CFBundleTypeRole</key>
                    <string>Viewer</string>
    </dict>
            </array>
        </dict>
        </plist>

    The following implementation of a **QApplication**  subclass prints the path
    to the file that was, for example, dropped on the Dock icon of the
    application.

    #include <QApplication>
        #include <QDebug>
        #include <QFileOpenEvent>
    #include <QPushButton>

        class MyApplication : public
    **QApplication**
        {
        public:
            MyApplication(int &argc, char
    **argv)
                : **QApplication** (argc, argv)
            {
            }
    bool event(**QEvent**  *event) override
            {
                if
    (event->type() == **QEvent** ::FileOpen) {
                    QFileOpenEvent
    *openEvent = static_cast<QFileOpenEvent *>(event);
    **qDebug** () << "Open file" << openEvent->file();
                }
    return **QApplication** ::event(event);
            }
        };
    """

    def clone(self) -> "QFileOpenEvent":
        ...

    def openFile(
        self, file: QtCore.QFile, flags: QtCore.QIODeviceBase.OpenModeFlag
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qfileopenevent.html#openFile

        **bool QFileOpenEvent::openFile(QFile & file , QIODevice::OpenMode flags
        ) const**

        Opens a **QFile**  on the **file** referenced by this event in the mode
        specified by **flags**. Returns `true` if successful; otherwise returns
        `false`.

        This is necessary as some files cannot be opened by name, but require
        specific information stored in this event.
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qfileopenevent.html#url

        **QUrl QFileOpenEvent::url() const**

        Returns the url that is being opened.
        """
        ...

    def file(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileopenevent.html#file

        **QString QFileOpenEvent::file() const**

        Returns the file that is being opened.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSizeGrip(QWidget):
    """
    https://doc.qt.io/qt-6/qsizegrip.html

    **Detailed Description**

    This widget works like the standard Windows resize handle. In the X11
    version this resize handle generally works differently from the one provided
    by the system if the X11 window manager does not support necessary modern
    post-ICCCM specifications.

    Put this widget anywhere in a widget tree and the user can use it to resize
    the top-level window or any widget with the **Qt::SubWindow**  flag set.
    Generally, this should be in the lower right-hand corner.

    Note that **QStatusBar**  already uses this widget, so if you have a status
    bar (e.g., you are using **QMainWindow** ), then you don't need to use this
    widget explicitly. The same goes for **QDialog** , for which you can just
    call **QDialog::setSizeGripEnabled** ().

    On some platforms the size grip automatically hides itself when the window
    is shown full screen or maximised.

    **Note:** On macOS, size grips are no longer part of the human interface
    guideline, and won't show unless used in a **QMdiSubWindow** . Set another
    style on size grips that you want to be visible in main windows.

    ![Screenshot of a Fusion style size grip](images/fusion-statusbar-
    sizegrip.png)A size grip widget at the bottom-right corner of a main window,
    shown in the **Fusion widget style** .

    The QSizeGrip class inherits **QWidget**  and reimplements the
    **mousePressEvent** () and **mouseMoveEvent** () functions to feature the
    resize functionality, and the **paintEvent** () function to render the size
    grip widget.

    **See also** **QStatusBar**  and **QWidget::windowState** ().
    """

    def __init__(self, parent: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#QSizeGrip

        **QSizeGrip::QSizeGrip(QWidget * parent )**

        Constructs a resize corner as a child widget of the given **parent**.
        """
        ...

    def hideEvent(self, hideEvent: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#hideEvent

        **[override virtual protected] void QSizeGrip::hideEvent(QHideEvent *
        hideEvent )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, showEvent: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#showEvent

        **[override virtual protected] void QSizeGrip::showEvent(QShowEvent *
        showEvent )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def moveEvent(self, moveEvent: QtGui.QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#moveEvent

        **[override virtual protected] void QSizeGrip::moveEvent(QMoveEvent *
        moveEvent )**

        Reimplements: **QWidget::moveEvent** (QMoveEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#event

        **[override virtual protected] bool QSizeGrip::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#eventFilter

        **[override virtual protected] bool QSizeGrip::eventFilter(QObject * o ,
        QEvent * e )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mouseMoveEvent

        **[override virtual protected] void
        QSizeGrip::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).

        Resizes the top-level widget containing this widget. The mouse move
        event is passed in the **event** parameter.
        """
        ...

    def mouseReleaseEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mouseReleaseEvent

        **[override virtual protected] void
        QSizeGrip::mouseReleaseEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mousePressEvent

        **[override virtual protected] void
        QSizeGrip::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).

        Receives the mouse press events for the widget, and primes the resize
        operation. The mouse press event is passed in the **event** parameter.
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#paintEvent

        **[override virtual protected] void QSizeGrip::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).

        Paints the resize grip.

        Resize grips are usually rendered as small diagonal textured lines in
        the lower-right corner. The paint event is passed in the **event**
        parameter.
        """
        ...

    def setVisible(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#setVisible

        **[override virtual] void QSizeGrip::setVisible(bool visible )**

        Reimplements an access function for property: **QWidget::visible** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#sizeHint

        **[override virtual] QSize QSizeGrip::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QPixelFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpixelformat.html

    **Detailed Description**

    In Qt there is a often a need to represent the layout of the pixels in a
    graphics buffer. Internally QPixelFormat stores everything in a 64 bit
    datastructure. This gives performance but also some limitations.

    QPixelFormat can describe 5 color channels and 1 alpha channel, each can use
    6 bits to describe the size of the color channel.

    The position of the alpha channel is described with a separate enum. This is
    to make it possible to describe **QImage**  formats like ARGB32, and also
    describe typical OpenGL formats like RBGA8888.

    How pixels are suppose to be read is determined by the
    **TypeInterpretation**  enum. It describes if color values are suppose to be
    read byte per byte, or if a pixel is suppose to be read as a complete int
    and then masked.

    There is no support for describing YUV's macro pixels. Instead a list of YUV
    formats has been made. When a QPixelFormat is describing a YUV format, the
    **bitsPerPixel**  value has been deduced by the YUV Layout enum. Also, the
    color channels should all be set to zero except the fifth color channel that
    should store the **bitsPerPixel**  value.

    **See also** **TypeInterpretation** .
    """

    class ByteOrder(enum.Enum):
        LittleEndian: QPixelFormat = ...
        BigEndian: QPixelFormat = ...
        CurrentSystemEndian: QPixelFormat = ...

    class YUVLayout(enum.Enum):
        YUV444: QPixelFormat = ...
        YUV422: QPixelFormat = ...
        YUV411: QPixelFormat = ...
        YUV420P: QPixelFormat = ...
        YUV420SP: QPixelFormat = ...
        YV12: QPixelFormat = ...
        UYVY: QPixelFormat = ...
        YUYV: QPixelFormat = ...
        NV12: QPixelFormat = ...
        NV21: QPixelFormat = ...
        IMC1: QPixelFormat = ...
        IMC2: QPixelFormat = ...
        IMC3: QPixelFormat = ...
        IMC4: QPixelFormat = ...
        Y8: QPixelFormat = ...
        Y16: QPixelFormat = ...

    class TypeInterpretation(enum.Enum):
        UnsignedInteger: QPixelFormat = ...
        UnsignedShort: QPixelFormat = ...
        UnsignedByte: QPixelFormat = ...
        FloatingPoint: QPixelFormat = ...

    class AlphaPremultiplied(enum.Enum):
        NotPremultiplied: QPixelFormat = ...
        Premultiplied: QPixelFormat = ...

    class AlphaPosition(enum.Enum):
        AtBeginning: QPixelFormat = ...
        AtEnd: QPixelFormat = ...

    class AlphaUsage(enum.Enum):
        UsesAlpha: QPixelFormat = ...
        IgnoresAlpha: QPixelFormat = ...

    class ColorModel(enum.Enum):
        RGB: QPixelFormat = ...
        BGR: QPixelFormat = ...
        Indexed: QPixelFormat = ...
        Grayscale: QPixelFormat = ...
        CMYK: QPixelFormat = ...
        HSL: QPixelFormat = ...
        HSV: QPixelFormat = ...
        YUV: QPixelFormat = ...
        Alpha: QPixelFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#QPixelFormat

        **QPixelFormat::QPixelFormat()**

        Creates a null pixelformat. This format maps to
        **QImage::Format_Invalid** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        mdl: "QPixelFormat.ColorModel",
        firstSize: int,
        secondSize: int,
        thirdSize: int,
        fourthSize: int,
        fifthSize: int,
        alfa: int,
        usage: "QPixelFormat.AlphaUsage",
        position: "QPixelFormat.AlphaPosition",
        premult: "QPixelFormat.AlphaPremultiplied",
        typeInterp: "QPixelFormat.TypeInterpretation",
        byteOrder: "QPixelFormat.ByteOrder" = ...,
        subEnum: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#QPixelFormat-1

        **QPixelFormat::QPixelFormat(QPixelFormat::ColorModel colorModel , uchar
        firstSize , uchar secondSize , uchar thirdSize , uchar fourthSize ,
        uchar fifthSize , uchar alphaSize , QPixelFormat::AlphaUsage alphaUsage
        , QPixelFormat::AlphaPosition alphaPosition ,
        QPixelFormat::AlphaPremultiplied premultiplied ,
        QPixelFormat::TypeInterpretation typeInterpretation ,
        QPixelFormat::ByteOrder byteOrder = CurrentSystemEndian, uchar subEnum =
        0)**

        Creates a QPixelFormat which assigns its data to the attributes.
        **colorModel** will be put into a buffer which is 4 bits long.

        **firstSize** **secondSize** **thirdSize** **fourthSize** **fifthSize**
        **alphaSize** are all meant to represent the size of a channel. The
        channels will be used for different uses dependent on the
        **colorModel**. For RGB the firstSize will represent the Red channel. On
        CMYK it will represent the value of the Cyan channel.

        **alphaUsage** represents if the alpha channel is used or not.

        **alphaPosition** is the position of the alpha channel.

        **premultiplied** represents if the alpha channel is already multiplied
        with the color channels.

        **typeInterpretation** is how the pixel is interpreted.

        **byteOrder** represents the endianness of the pixelformat. This
        defaults to **CurrentSystemEndian** .

        **subEnum** is used for colorModels that have to store some extra
        information with supplying an extra enum. This is used by YUV to store
        the YUV type The default value is 0.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPixelFormat") -> None:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#QPixelFormat

        **QPixelFormat::QPixelFormat()**

        Creates a null pixelformat. This format maps to
        **QImage::Format_Invalid** .
        """
        ...

    def subEnum(self) -> int:
        ...

    def yuvLayout(self) -> "QPixelFormat.YUVLayout":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#yuvLayout

        **QPixelFormat::YUVLayout QPixelFormat::yuvLayout() const**

        Accessor function for the **YUVLayout** . It is difficult to describe
        the color channels of a YUV pixel format since YUV color model uses
        macro pixels. Instead the layout of the pixels are stored as an enum.
        """
        ...

    def byteOrder(self) -> "QPixelFormat.ByteOrder":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#byteOrder

        **QPixelFormat::ByteOrder QPixelFormat::byteOrder() const**

        The byte order is almost always set the byte order of the current
        system. However, it can be useful to describe some YUV formats. This
        function should never return **QPixelFormat::CurrentSystemEndian**  as
        this value is translated to a endian value in the constructor.
        """
        ...

    def typeInterpretation(self) -> "QPixelFormat.TypeInterpretation":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#typeInterpretation

        **QPixelFormat::TypeInterpretation QPixelFormat::typeInterpretation()
        const**

        Accessor function for the type representation of a color channel or a
        pixel.

        **See also** **TypeInterpretation** .
        """
        ...

    def premultiplied(self) -> "QPixelFormat.AlphaPremultiplied":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#premultiplied

        **QPixelFormat::AlphaPremultiplied QPixelFormat::premultiplied() const**

        Accessor function for the **AlphaPremultiplied**  enum. This indicates
        if the alpha channel is multiplied in to the color channels.
        """
        ...

    def alphaPosition(self) -> "QPixelFormat.AlphaPosition":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#alphaPosition

        **QPixelFormat::AlphaPosition QPixelFormat::alphaPosition() const**

        Accessor function for alphaPosition.
        """
        ...

    def alphaUsage(self) -> "QPixelFormat.AlphaUsage":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#alphaUsage

        **QPixelFormat::AlphaUsage QPixelFormat::alphaUsage() const**

        Accessor function for alphaUsage.
        """
        ...

    def bitsPerPixel(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#bitsPerPixel

        **uchar QPixelFormat::bitsPerPixel() const**

        Accessor function for the bits used per pixel. This function returns the
        sum of the color channels + the size of the alpha channel.
        """
        ...

    def alphaSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#alphaSize

        **uchar QPixelFormat::alphaSize() const**

        Accessor function for the alpha channel size.
        """
        ...

    def brightnessSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#brightnessSize

        **uchar QPixelFormat::brightnessSize() const**

        Accessor function for the brightness channel size.
        """
        ...

    def lightnessSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#lightnessSize

        **uchar QPixelFormat::lightnessSize() const**

        Accessor function for the lightness channel size.
        """
        ...

    def saturationSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#saturationSize

        **uchar QPixelFormat::saturationSize() const**

        Accessor function for the saturation channel size.
        """
        ...

    def hueSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#hueSize

        **uchar QPixelFormat::hueSize() const**

        Accessor function for the hue channel size.
        """
        ...

    def blackSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#blackSize

        **uchar QPixelFormat::blackSize() const**

        Accessor function for the black/key color channel.
        """
        ...

    def yellowSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#yellowSize

        **uchar QPixelFormat::yellowSize() const**

        Accessor function for the yellow color channel.
        """
        ...

    def magentaSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#magentaSize

        **uchar QPixelFormat::magentaSize() const**

        Accessor function for the megenta color channel.
        """
        ...

    def cyanSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#cyanSize

        **uchar QPixelFormat::cyanSize() const**

        Accessor function for the cyan color channel.
        """
        ...

    def blueSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#blueSize

        **uchar QPixelFormat::blueSize() const**

        Accessor function for the size of the blue color channel.
        """
        ...

    def greenSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#greenSize

        **uchar QPixelFormat::greenSize() const**

        Accessor function for the size of the green color channel.
        """
        ...

    def redSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#redSize

        **uchar QPixelFormat::redSize() const**

        Accessor function for the size of the red color channel.
        """
        ...

    def channelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixelformat.html#channelCount

        **uchar QPixelFormat::channelCount() const**

        Accessor function for getting the channelCount. Channel Count is deduced
        by color channels with a size > 0 and if the size of the alpha channel
        is > 0.
        """
        ...

    def colorModel(self) -> "QPixelFormat.ColorModel":
        """
        https://doc.qt.io/qt-6/qpixelformat.html#colorModel

        **QPixelFormat::ColorModel QPixelFormat::colorModel() const**

        Accessor function for getting the colorModel.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCryptographicHash(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcryptographichash.html

    **Detailed Description**

    QCryptographicHash can be used to generate cryptographic hashes of binary or
    text data.

    Refer to the documentation of the **QCryptographicHash::Algorithm**  enum
    for a list of the supported algorithms.
    """

    class Algorithm(enum.Enum):
        Md4: QCryptographicHash = ...
        Md5: QCryptographicHash = ...
        Sha1: QCryptographicHash = ...
        Sha224: QCryptographicHash = ...
        Sha256: QCryptographicHash = ...
        Sha384: QCryptographicHash = ...
        Sha512: QCryptographicHash = ...
        Sha3_224: QCryptographicHash = ...
        Sha3_256: QCryptographicHash = ...
        Sha3_384: QCryptographicHash = ...
        Sha3_512: QCryptographicHash = ...
        Keccak_224: QCryptographicHash = ...
        Keccak_256: QCryptographicHash = ...
        Keccak_384: QCryptographicHash = ...
        Keccak_512: QCryptographicHash = ...
        Blake2b_160: QCryptographicHash = ...
        Blake2b_256: QCryptographicHash = ...
        Blake2b_384: QCryptographicHash = ...
        Blake2b_512: QCryptographicHash = ...
        Blake2s_128: QCryptographicHash = ...
        Blake2s_160: QCryptographicHash = ...
        Blake2s_224: QCryptographicHash = ...
        Blake2s_256: QCryptographicHash = ...

    def __init__(self, method: "QCryptographicHash.Algorithm") -> None:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#QCryptographicHash

        **QCryptographicHash::QCryptographicHash(QCryptographicHash::Algorithm
        method )**

        Constructs an object that can be used to create a cryptographic hash
        from data using **method**.
        """
        ...

    @staticmethod
    def hashLength(method: "QCryptographicHash.Algorithm") -> int:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#hashLength

        **[static, since 5.12] int
        QCryptographicHash::hashLength(QCryptographicHash::Algorithm method )**

        Returns the size of the output of the selected hash **method** in bytes.

        This function was introduced in Qt 5.12.
        """
        ...

    @staticmethod
    def hash(data: QByteArray, method: "QCryptographicHash.Algorithm") -> QByteArray:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#hash

        **[static] QByteArray QCryptographicHash::hash(const QByteArray & data ,
        QCryptographicHash::Algorithm method )**

        Returns the hash of **data** using **method**.
        """
        ...

    def result(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#result

        **QByteArray QCryptographicHash::result() const**

        Returns the final hash value.

        **See also** **QByteArray::toHex** ().
        """
        ...

    @typing.overload
    def addData(self, data: bytes) -> None:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#addData

        **void QCryptographicHash::addData(const char * data , qsizetype length
        )**

        Adds the first **length** chars of **data** to the cryptographic hash.
        """
        ...

    @typing.overload
    def addData(self, data: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#addData-1

        **void QCryptographicHash::addData(const QByteArray & data )**

        This function overloads addData().
        """
        ...

    @typing.overload
    def addData(self, device: QIODevice) -> bool:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#addData-2

        **[since 5.0] bool QCryptographicHash::addData(QIODevice * device )**

        Reads the data from the open **QIODevice**  **device** until it ends and
        hashes it. Returns `true` if reading was successful.

        This function was introduced in Qt 5.0.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qcryptographichash.html#reset

        **void QCryptographicHash::reset()**

        Resets the object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QTiltSensor(QSensor):
    """
    https://doc.qt.io/qt-6/qtiltsensor.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QTiltReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QTiltReading** .

    **See also** **QTiltReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#QTiltSensor

        **QTiltSensor::QTiltSensor(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def calibrate(self) -> None:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#calibrate

        **[invokable] void QTiltSensor::calibrate()**

        Calibrates the tilt sensor. Uses the current tilt angles as 0 degrees.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def reading(self) -> QTiltReading:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#reading

        **QTiltReading *QTiltSensor::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomCDATASection(QDomText):
    """
    https://doc.qt.io/qt-6/qdomcdatasection.html

    **Detailed Description**

    CDATA sections are used to escape blocks of text containing characters that
    would otherwise be regarded as markup. The only delimiter that is recognized
    in a CDATA section is the "]]&gt;" string that terminates the CDATA section.
    CDATA sections cannot be nested. Their primary purpose is for including
    material such as XML fragments, without needing to escape all the
    delimiters.

    Adjacent QDomCDATASection nodes are not merged by the
    **QDomNode::normalize** () function.

    For further information about the Document Object Model see
    <http://www.w3.org/TR/REC-DOM-Level-1/> and <http://www.w3.org/TR/DOM-
    Level-2-Core/>. For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomcdatasection.html#QDomCDATASection

        **QDomCDATASection::QDomCDATASection()**

        Constructs an empty CDATA section. To create a CDATA section with
        content, use the **QDomDocument::createCDATASection** () function.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomCDATASection") -> None:
        """
        https://doc.qt.io/qt-6/qdomcdatasection.html#QDomCDATASection-1

        **QDomCDATASection::QDomCDATASection(const QDomCDATASection & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomcdatasection.html#nodeType

        **QDomNode::NodeType QDomCDATASection::nodeType() const**

        Returns `CDATASection`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QFileSystemWatcher(QObject):
    """
    https://doc.qt.io/qt-6/qfilesystemwatcher.html

    **Detailed Description**

    QFileSystemWatcher monitors the file system for changes to files and
    directories by watching a list of specified paths.

    Call **addPath** () to watch a particular file or directory. Multiple paths
    can be added using the **addPaths** () function. Existing paths can be
    removed by using the **removePath** () and **removePaths** () functions.

    QFileSystemWatcher examines each path added to it. Files that have been
    added to the QFileSystemWatcher can be accessed using the **files** ()
    function, and directories using the **directories** () function.

    The **fileChanged** () signal is emitted when a file has been modified,
    renamed or removed from disk. Similarly, the **directoryChanged** () signal
    is emitted when a directory or its contents is modified or removed. Note
    that QFileSystemWatcher stops monitoring files once they have been renamed
    or removed from disk, and directories once they have been removed from disk.

    * **Notes** :
        * On systems running a Linux kernel without inotify
    support, file systems that contain watched paths cannot be unmounted.
        *
    The act of monitoring files and directories for modifications consumes
    system resources. This implies there is a limit to the number of files and
    directories your process can monitor simultaneously. On all BSD variants,
    for example, an open file descriptor is required for each monitored file.
    Some system limits the number of open file descriptors to 256 by default.
    This means that **addPath** () and **addPaths** () will fail if your process
    tries to add more than 256 files or directories to the file system monitor.
    Also note that your process may have other file descriptors open in addition
    to the ones for files being monitored, and these other open descriptors also
    count in the total. macOS uses a different backend and does not suffer from
    this issue.

    **See also** **QFile**  and **QDir** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#QFileSystemWatcher

        **QFileSystemWatcher::QFileSystemWatcher(QObject * parent = nullptr)**

        Constructs a new file system watcher object with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, paths: typing.Iterable[str], parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#QFileSystemWatcher-1

        **QFileSystemWatcher::QFileSystemWatcher(const QStringList & paths ,
        QObject * parent = nullptr)**

        Constructs a new file system watcher object with the given **parent**
        which monitors the specified **paths** list.
        """
        ...

    def removePaths(self, files: typing.Iterable[str]) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#removePaths

        **QStringList QFileSystemWatcher::removePaths(const QStringList & paths
        )**

        Removes the specified **paths** from the file system watcher.

        The return value is a list of paths which were not able to be unwatched
        successfully.

        Reasons for watch removal failing are generally system-dependent, but
        may be due to the path having already been deleted, for example.

        **See also** **removePath** () and **addPaths** ().
        """
        ...

    def removePath(self, file: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#removePath

        **bool QFileSystemWatcher::removePath(const QString & path )**

        Removes the specified **path** from the file system watcher.

        If the watch is successfully removed, true is returned.

        Reasons for watch removal failing are generally system-dependent, but
        may be due to the path having already been deleted, for example.

        **See also** **removePaths** () and **addPath** ().
        """
        ...

    def files(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#files

        **QStringList QFileSystemWatcher::files() const**

        Returns a list of paths to files that are being watched.

        **See also** **directories** ().
        """
        ...

    def directories(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#directories

        **QStringList QFileSystemWatcher::directories() const**

        Returns a list of paths to directories that are being watched.

        **See also** **files** ().
        """
        ...

    def addPaths(self, files: typing.Iterable[str]) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#addPaths

        **QStringList QFileSystemWatcher::addPaths(const QStringList & paths )**

        Adds each path in **paths** to the file system watcher. Paths are not
        added if they not exist, or if they are already being monitored by the
        file system watcher.

        If a path specifies a directory, the **directoryChanged** () signal will
        be emitted when the path is modified or removed from disk; otherwise the
        **fileChanged** () signal is emitted when the path is modified, renamed,
        or removed.

        The return value is a list of paths that could not be watched.

        Reasons for a watch failure are generally system-dependent, but may
        include the resource not existing, access failures, or the total watch
        count limit, if the platform has one.

        **Note:** There may be a system dependent limit to the number of files
        and directories that can be monitored simultaneously. If this limit has
        been reached, the excess **paths** will not be monitored, and they will
        be added to the returned **QStringList** .

        **See also** **addPath** () and **removePaths** ().
        """
        ...

    def addPath(self, file: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#addPath

        **bool QFileSystemWatcher::addPath(const QString & path )**

        Adds **path** to the file system watcher if **path** exists. The path is
        not added if it does not exist, or if it is already being monitored by
        the file system watcher.

        If **path** specifies a directory, the **directoryChanged** () signal
        will be emitted when **path** is modified or removed from disk;
        otherwise the **fileChanged** () signal is emitted when **path** is
        modified, renamed or removed.

        If the watch was successful, true is returned.

        Reasons for a watch failure are generally system-dependent, but may
        include the resource not existing, access failures, or the total watch
        count limit, if the platform has one.

        **Note:** There may be a system dependent limit to the number of files
        and directories that can be monitored simultaneously. If this limit is
        been reached, **path** will not be monitored, and false is returned.

        **See also** **addPaths** () and **removePath** ().
        """
        ...

    @property
    def directoryChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#directoryChanged

        **[private signal] void QFileSystemWatcher::directoryChanged(const
        QString & path )**

        This signal is emitted when the directory at a specified **path** is
        modified (e.g., when a file is added or deleted) or removed from disk.
        Note that if there are several changes during a short period of time,
        some of the changes might not emit this signal. However, the last change
        in the sequence of changes will always generate this signal.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **fileChanged** ().
        """
        ...

    @property
    def fileChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfilesystemwatcher.html#fileChanged

        **[private signal] void QFileSystemWatcher::fileChanged(const QString &
        path )**

        This signal is emitted when the file at the specified **path** is
        modified, renamed or removed from disk.

        **Note:** As a safety measure, many applications save an open file by
        writing a new file and then deleting the old one. In your slot function,
        you can check `watcher.files().contains(path)`. If it returns `false`,
        check whether the file still exists and then call `addPath()` to
        continue watching it.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **directoryChanged** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import qGray as qGray
from ._functions import qGray as qGray
from ._functions import qRgba as qRgba
from ._functions import qRgb as qRgb
from ._functions import qAlpha as qAlpha
from ._functions import qAlpha as qAlpha
from ._functions import qBlue as qBlue
from ._functions import qBlue as qBlue
from ._functions import qGreen as qGreen
from ._functions import qGreen as qGreen
from ._functions import qRed as qRed
from ._functions import qRed as qRed
from ._functions import qUnpremultiply as qUnpremultiply
from ._functions import qUnpremultiply as qUnpremultiply
from ._functions import qPremultiply as qPremultiply
from ._functions import qPremultiply as qPremultiply
from ._functions import qRgba64 as qRgba64
from ._functions import qRgba64 as qRgba64
from ._functions import qPixelFormatAlpha as qPixelFormatAlpha
from ._functions import qPixelFormatYuv as qPixelFormatYuv
from ._functions import qPixelFormatHsv as qPixelFormatHsv
from ._functions import qPixelFormatHsl as qPixelFormatHsl
from ._functions import qPixelFormatCmyk as qPixelFormatCmyk
from ._functions import qPixelFormatGrayscale as qPixelFormatGrayscale
from ._functions import qPixelFormatRgba as qPixelFormatRgba
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qt_set_sequence_auto_mnemonic as qt_set_sequence_auto_mnemonic
from ._QAbstractFileIconProvider import (
    QAbstractFileIconProvider as QAbstractFileIconProvider,
)
from ._QAbstractTextDocumentLayout import (
    QAbstractTextDocumentLayout as QAbstractTextDocumentLayout,
)
from ._QTextObjectInterface import QTextObjectInterface as QTextObjectInterface
from ._QAction import QAction as QAction
from ._QActionGroup import QActionGroup as QActionGroup
from ._QBackingStore import QBackingStore as QBackingStore
from ._QPaintDevice import QPaintDevice as QPaintDevice
from ._QPixmap import QPixmap as QPixmap
from ._QBitmap import QBitmap as QBitmap
from ._QColor import QColor as QColor
from ._QColorConstants import QColorConstants as QColorConstants
from ._QBrush import QBrush as QBrush
from ._QGradient import QGradient as QGradient
from ._QLinearGradient import QLinearGradient as QLinearGradient
from ._QRadialGradient import QRadialGradient as QRadialGradient
from ._QConicalGradient import QConicalGradient as QConicalGradient
from ._QClipboard import QClipboard as QClipboard
from ._QColorSpace import QColorSpace as QColorSpace
from ._QColorTransform import QColorTransform as QColorTransform
from ._QCursor import QCursor as QCursor
from ._QDesktopServices import QDesktopServices as QDesktopServices
from ._QDrag import QDrag as QDrag
from ._QInputEvent import QInputEvent as QInputEvent
from ._QKeyEvent import QKeyEvent as QKeyEvent
from ._QFocusEvent import QFocusEvent as QFocusEvent
from ._QPaintEvent import QPaintEvent as QPaintEvent
from ._QMoveEvent import QMoveEvent as QMoveEvent
from ._QResizeEvent import QResizeEvent as QResizeEvent
from ._QCloseEvent import QCloseEvent as QCloseEvent
from ._QIconDragEvent import QIconDragEvent as QIconDragEvent
from ._QShowEvent import QShowEvent as QShowEvent
from ._QHideEvent import QHideEvent as QHideEvent
from ._QContextMenuEvent import QContextMenuEvent as QContextMenuEvent
from ._QInputMethodEvent import QInputMethodEvent as QInputMethodEvent
from ._QInputMethodQueryEvent import QInputMethodQueryEvent as QInputMethodQueryEvent
from ._QDropEvent import QDropEvent as QDropEvent
from ._QDragMoveEvent import QDragMoveEvent as QDragMoveEvent
from ._QDragEnterEvent import QDragEnterEvent as QDragEnterEvent
from ._QDragLeaveEvent import QDragLeaveEvent as QDragLeaveEvent
from ._QHelpEvent import QHelpEvent as QHelpEvent
from ._QStatusTipEvent import QStatusTipEvent as QStatusTipEvent
from ._QWhatsThisClickedEvent import QWhatsThisClickedEvent as QWhatsThisClickedEvent
from ._QActionEvent import QActionEvent as QActionEvent
from ._QFileOpenEvent import QFileOpenEvent as QFileOpenEvent
from ._QShortcutEvent import QShortcutEvent as QShortcutEvent
from ._QWindowStateChangeEvent import QWindowStateChangeEvent as QWindowStateChangeEvent
from ._QExposeEvent import QExposeEvent as QExposeEvent
from ._QScrollPrepareEvent import QScrollPrepareEvent as QScrollPrepareEvent
from ._QScrollEvent import QScrollEvent as QScrollEvent
from ._QPlatformSurfaceEvent import QPlatformSurfaceEvent as QPlatformSurfaceEvent
from ._QPointerEvent import QPointerEvent as QPointerEvent
from ._QSinglePointEvent import QSinglePointEvent as QSinglePointEvent
from ._QEnterEvent import QEnterEvent as QEnterEvent
from ._QMouseEvent import QMouseEvent as QMouseEvent
from ._QHoverEvent import QHoverEvent as QHoverEvent
from ._QWheelEvent import QWheelEvent as QWheelEvent
from ._QTabletEvent import QTabletEvent as QTabletEvent
from ._QNativeGestureEvent import QNativeGestureEvent as QNativeGestureEvent
from ._QTouchEvent import QTouchEvent as QTouchEvent
from ._QEventPoint import QEventPoint as QEventPoint
from ._QFileSystemModel import QFileSystemModel as QFileSystemModel
from ._QFont import QFont as QFont
from ._QFontDatabase import QFontDatabase as QFontDatabase
from ._QFontInfo import QFontInfo as QFontInfo
from ._QFontMetrics import QFontMetrics as QFontMetrics
from ._QFontMetricsF import QFontMetricsF as QFontMetricsF
from ._QMatrix4x3 import QMatrix4x3 as QMatrix4x3
from ._QMatrix4x2 import QMatrix4x2 as QMatrix4x2
from ._QMatrix3x4 import QMatrix3x4 as QMatrix3x4
from ._QMatrix3x3 import QMatrix3x3 as QMatrix3x3
from ._QMatrix3x2 import QMatrix3x2 as QMatrix3x2
from ._QMatrix2x4 import QMatrix2x4 as QMatrix2x4
from ._QMatrix2x3 import QMatrix2x3 as QMatrix2x3
from ._QMatrix2x2 import QMatrix2x2 as QMatrix2x2
from ._QGlyphRun import QGlyphRun as QGlyphRun
from ._QGuiApplication import QGuiApplication as QGuiApplication
from ._QIcon import QIcon as QIcon
from ._QIconEngine import QIconEngine as QIconEngine
from ._QImage import QImage as QImage
from ._QImageIOHandler import QImageIOHandler as QImageIOHandler
from ._QImageReader import QImageReader as QImageReader
from ._QImageWriter import QImageWriter as QImageWriter
from ._QInputDevice import QInputDevice as QInputDevice
from ._QInputMethod import QInputMethod as QInputMethod
from ._QKeySequence import QKeySequence as QKeySequence
from ._QMatrix4x4 import QMatrix4x4 as QMatrix4x4
from ._QMovie import QMovie as QMovie
from ._QSurface import QSurface as QSurface
from ._QOffscreenSurface import QOffscreenSurface as QOffscreenSurface
from ._QOpenGLContextGroup import QOpenGLContextGroup as QOpenGLContextGroup
from ._QOpenGLContext import QOpenGLContext as QOpenGLContext
from ._QPagedPaintDevice import QPagedPaintDevice as QPagedPaintDevice
from ._QPageLayout import QPageLayout as QPageLayout
from ._QPageRanges import QPageRanges as QPageRanges
from ._QPageSize import QPageSize as QPageSize
from ._QWindow import QWindow as QWindow
from ._QPaintDeviceWindow import QPaintDeviceWindow as QPaintDeviceWindow
from ._QTextItem import QTextItem as QTextItem
from ._QPaintEngine import QPaintEngine as QPaintEngine
from ._QPaintEngineState import QPaintEngineState as QPaintEngineState
from ._QPainter import QPainter as QPainter
from ._QPainterPath import QPainterPath as QPainterPath
from ._QPainterPathStroker import QPainterPathStroker as QPainterPathStroker
from ._QPalette import QPalette as QPalette
from ._QPdfWriter import QPdfWriter as QPdfWriter
from ._QPen import QPen as QPen
from ._QPicture import QPicture as QPicture
from ._QPixelFormat import QPixelFormat as QPixelFormat
from ._QPixmapCache import QPixmapCache as QPixmapCache
from ._QPointingDeviceUniqueId import QPointingDeviceUniqueId as QPointingDeviceUniqueId
from ._QPointingDevice import QPointingDevice as QPointingDevice
from ._QPolygon import QPolygon as QPolygon
from ._QPolygonF import QPolygonF as QPolygonF
from ._QQuaternion import QQuaternion as QQuaternion
from ._QRasterWindow import QRasterWindow as QRasterWindow
from ._QRawFont import QRawFont as QRawFont
from ._QRegion import QRegion as QRegion
from ._QRgba64 import QRgba64 as QRgba64
from ._QScreen import QScreen as QScreen
from ._QSessionManager import QSessionManager as QSessionManager
from ._QShortcut import QShortcut as QShortcut
from ._QStandardItemModel import QStandardItemModel as QStandardItemModel
from ._QStandardItem import QStandardItem as QStandardItem
from ._QStaticText import QStaticText as QStaticText
from ._QStyleHints import QStyleHints as QStyleHints
from ._QSurfaceFormat import QSurfaceFormat as QSurfaceFormat
from ._QSyntaxHighlighter import QSyntaxHighlighter as QSyntaxHighlighter
from ._QTextCursor import QTextCursor as QTextCursor
from ._QTextDocument import QTextDocument as QTextDocument
from ._QTextDocumentFragment import QTextDocumentFragment as QTextDocumentFragment
from ._QTextDocumentWriter import QTextDocumentWriter as QTextDocumentWriter
from ._QTextLength import QTextLength as QTextLength
from ._QTextFormat import QTextFormat as QTextFormat
from ._QTextCharFormat import QTextCharFormat as QTextCharFormat
from ._QTextBlockFormat import QTextBlockFormat as QTextBlockFormat
from ._QTextListFormat import QTextListFormat as QTextListFormat
from ._QTextImageFormat import QTextImageFormat as QTextImageFormat
from ._QTextFrameFormat import QTextFrameFormat as QTextFrameFormat
from ._QTextTableFormat import QTextTableFormat as QTextTableFormat
from ._QTextTableCellFormat import QTextTableCellFormat as QTextTableCellFormat
from ._QTextInlineObject import QTextInlineObject as QTextInlineObject
from ._QTextLayout import QTextLayout as QTextLayout
from ._QTextLine import QTextLine as QTextLine
from ._QTextObject import QTextObject as QTextObject
from ._QTextBlockGroup import QTextBlockGroup as QTextBlockGroup
from ._QTextList import QTextList as QTextList
from ._QTextFrame import QTextFrame as QTextFrame
from ._QTextBlock import QTextBlock as QTextBlock
from ._QTextFragment import QTextFragment as QTextFragment
from ._QTextBlockUserData import QTextBlockUserData as QTextBlockUserData
from ._QTextOption import QTextOption as QTextOption
from ._QTextTableCell import QTextTableCell as QTextTableCell
from ._QTextTable import QTextTable as QTextTable
from ._QTransform import QTransform as QTransform
from ._QUndoGroup import QUndoGroup as QUndoGroup
from ._QUndoCommand import QUndoCommand as QUndoCommand
from ._QUndoStack import QUndoStack as QUndoStack
from ._QValidator import QValidator as QValidator
from ._QIntValidator import QIntValidator as QIntValidator
from ._QDoubleValidator import QDoubleValidator as QDoubleValidator
from ._QRegularExpressionValidator import (
    QRegularExpressionValidator as QRegularExpressionValidator,
)
from ._QVector2D import QVector2D as QVector2D
from ._QVector3D import QVector3D as QVector3D
from ._QVector4D import QVector4D as QVector4D



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QInputDialog(QDialog):
    """
    https://doc.qt.io/qt-6/qinputdialog.html

    **Detailed Description**

    The input value can be a string, a number or an item from a list. A label
    must be set to tell the user what they should enter.

    Five static convenience functions are provided: **getText** (),
    **getMultiLineText** (), **getInt** (), **getDouble** (), and **getItem**
    (). All the functions can be used in a similar way, for example:

    bool ok;
            **QString**  text = **QInputDialog** ::getText(this,
    tr("QInputDialog::getText()"),
    tr("User name:"), **QLineEdit** ::Normal,
    **QDir** ::home().dirName(), &ok);
            if (ok && !text.isEmpty())
    textLabel->setText(text);

    The `ok` variable is set to true if the user clicks **OK** ; otherwise, it
    is set to false.

    ![Input Dialogs](images/inputdialogs.png)

    The **Standard Dialogs**  example shows how to use QInputDialog as well as
    other built-in Qt dialogs.

    **See also** **QMessageBox**  and **Standard Dialogs Example** .
    """

    class InputMode(enum.Enum):
        TextInput: QInputDialog = ...
        IntInput: QInputDialog = ...
        DoubleInput: QInputDialog = ...

    class InputDialogOption(enum.Flag):
        NoButtons: QInputDialog = ...
        UseListViewForComboBoxItems: QInputDialog = ...
        UsePlainTextEditForTextInput: QInputDialog = ...

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#QInputDialog

        **QInputDialog::QInputDialog(QWidget * parent = nullptr, Qt::WindowFlags
        flags = Qt::WindowFlags())**

        Constructs a new input dialog with the given **parent** and window
        **flags**.
        """
        ...

    def doubleStep(self) -> float:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleStep-prop

        **[since 5.10] doubleStep : double**

        This property holds the step by which the double value is increased and
        decreased

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        This property was introduced in Qt 5.10.

        **Access functions:**

        double **doubleStep** () const
        void **setDoubleStep** (double **step**
        )
        """
        ...

    def setDoubleStep(self, step: float) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleStep-prop

        **[since 5.10] doubleStep : double**

        This property holds the step by which the double value is increased and
        decreased

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        This property was introduced in Qt 5.10.

        **Access functions:**

        double **doubleStep** () const
        void **setDoubleStep** (double **step**
        )
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#done

        **[override virtual] void QInputDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).

        Closes the dialog and sets its result code to **result**. If this dialog
        is shown with **exec** (), done() causes the local event loop to finish,
        and **exec** () to return **result**.

        **See also** **QDialog::done** ().
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#setVisible

        **[override virtual] void QInputDialog::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#sizeHint

        **[override virtual] QSize QInputDialog::sizeHint() const**

        Reimplements: **QDialog::sizeHint() const** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#minimumSizeHint

        **[override virtual] QSize QInputDialog::minimumSizeHint() const**

        Reimplements: **QDialog::minimumSizeHint() const** .
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#open

        **void QInputDialog::open(QObject * receiver , const char * member )**

        This function connects one of its signals to the slot specified by
        **receiver** and **member**. The specific signal depends on the
        arguments that are specified in **member**. These are:

        * **textValueSelected** () if **member** has a **QString**  for its
        first argument.
          * **intValueSelected** () if **member** has an int for
        its first argument.
          * **doubleValueSelected** () if **member** has a
        double for its first argument.
          * **accepted** () if **member** has NO
        arguments.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#open

        **void QInputDialog::open(QObject * receiver , const char * member )**

        This function connects one of its signals to the slot specified by
        **receiver** and **member**. The specific signal depends on the
        arguments that are specified in **member**. These are:

        * **textValueSelected** () if **member** has a **QString**  for its
        first argument.
          * **intValueSelected** () if **member** has an int for
        its first argument.
          * **doubleValueSelected** () if **member** has a
        double for its first argument.
          * **accepted** () if **member** has NO
        arguments.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def cancelButtonText(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#cancelButtonText-prop

        **cancelButtonText : QString**

        This property holds the text for the button used to cancel the dialog

        **Access functions:**

        QString **cancelButtonText** () const
        void **setCancelButtonText**
        (const QString & **text** )
        """
        ...

    def setCancelButtonText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#cancelButtonText-prop

        **cancelButtonText : QString**

        This property holds the text for the button used to cancel the dialog

        **Access functions:**

        QString **cancelButtonText** () const
        void **setCancelButtonText**
        (const QString & **text** )
        """
        ...

    def okButtonText(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#okButtonText-prop

        **okButtonText : QString**

        This property holds the text for the button used to accept the entry in
        the dialog

        **Access functions:**

        QString **okButtonText** () const
        void **setOkButtonText** (const
        QString & **text** )
        """
        ...

    def setOkButtonText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#okButtonText-prop

        **okButtonText : QString**

        This property holds the text for the button used to accept the entry in
        the dialog

        **Access functions:**

        QString **okButtonText** () const
        void **setOkButtonText** (const
        QString & **text** )
        """
        ...

    def doubleDecimals(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleDecimals-prop

        **doubleDecimals : int**

        sets the precision of the double spinbox in decimals

        **Access functions:**

        int **doubleDecimals** () const
        void **setDoubleDecimals** (int
        **decimals** )

        **See also** **QDoubleSpinBox::setDecimals** ().
        """
        ...

    def setDoubleDecimals(self, decimals: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleDecimals-prop

        **doubleDecimals : int**

        sets the precision of the double spinbox in decimals

        **Access functions:**

        int **doubleDecimals** () const
        void **setDoubleDecimals** (int
        **decimals** )

        **See also** **QDoubleSpinBox::setDecimals** ().
        """
        ...

    def setDoubleRange(self, min: float, max: float) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#setDoubleRange

        **void QInputDialog::setDoubleRange(double min , double max )**

        Sets the range of double precision floating point values accepted by the
        dialog when used in **DoubleInput**  mode, with minimum and maximum
        values specified by **min** and **max** respectively.
        """
        ...

    def doubleMaximum(self) -> float:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleMaximum-prop

        **doubleMaximum : double**

        This property holds the maximum double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleMaximum** () const
        void **setDoubleMaximum** (double
        **max** )
        """
        ...

    def setDoubleMaximum(self, max: float) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleMaximum-prop

        **doubleMaximum : double**

        This property holds the maximum double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleMaximum** () const
        void **setDoubleMaximum** (double
        **max** )
        """
        ...

    def doubleMinimum(self) -> float:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleMinimum-prop

        **doubleMinimum : double**

        This property holds the minimum double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleMinimum** () const
        void **setDoubleMinimum** (double
        **min** )
        """
        ...

    def setDoubleMinimum(self, min: float) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleMinimum-prop

        **doubleMinimum : double**

        This property holds the minimum double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleMinimum** () const
        void **setDoubleMinimum** (double
        **min** )
        """
        ...

    def doubleValue(self) -> float:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleValue-prop

        **doubleValue : int**

        This property holds the current double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleValue** () const
        void **setDoubleValue** (double
        **value** )

        **Notifier signal:**

        void ****doubleValueChanged** ** (double **value** )
        """
        ...

    def setDoubleValue(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleValue-prop

        **doubleValue : int**

        This property holds the current double precision floating point value
        accepted as input

        This property is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Access functions:**

        double **doubleValue** () const
        void **setDoubleValue** (double
        **value** )

        **Notifier signal:**

        void ****doubleValueChanged** ** (double **value** )
        """
        ...

    def intStep(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intStep-prop

        **intStep : int**

        This property holds the step by which the integer value is increased and
        decreased

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intStep** () const
        void **setIntStep** (int **step** )
        """
        ...

    def setIntStep(self, step: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intStep-prop

        **intStep : int**

        This property holds the step by which the integer value is increased and
        decreased

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intStep** () const
        void **setIntStep** (int **step** )
        """
        ...

    def setIntRange(self, min: int, max: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#setIntRange

        **void QInputDialog::setIntRange(int min , int max )**

        Sets the range of integer values accepted by the dialog when used in
        **IntInput**  mode, with minimum and maximum values specified by **min**
        and **max** respectively.
        """
        ...

    def intMaximum(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intMaximum-prop

        **intMaximum : int**

        This property holds the maximum integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intMaximum** () const
        void **setIntMaximum** (int **max** )
        """
        ...

    def setIntMaximum(self, max: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intMaximum-prop

        **intMaximum : int**

        This property holds the maximum integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intMaximum** () const
        void **setIntMaximum** (int **max** )
        """
        ...

    def intMinimum(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intMinimum-prop

        **intMinimum : int**

        This property holds the minimum integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intMinimum** () const
        void **setIntMinimum** (int **min** )
        """
        ...

    def setIntMinimum(self, min: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intMinimum-prop

        **intMinimum : int**

        This property holds the minimum integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intMinimum** () const
        void **setIntMinimum** (int **min** )
        """
        ...

    def intValue(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intValue-prop

        **intValue : int**

        This property holds the current integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intValue** () const
        void **setIntValue** (int **value** )

        **Notifier signal:**

        void ****intValueChanged** ** (int **value** )
        """
        ...

    def setIntValue(self, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intValue-prop

        **intValue : int**

        This property holds the current integer value accepted as input

        This property is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Access functions:**

        int **intValue** () const
        void **setIntValue** (int **value** )

        **Notifier signal:**

        void ****intValueChanged** ** (int **value** )
        """
        ...

    def comboBoxItems(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#comboBoxItems-prop

        **comboBoxItems : QStringList**

        This property holds the items used in the combo box for the input dialog

        **Access functions:**

        QStringList **comboBoxItems** () const
        void **setComboBoxItems**
        (const QStringList & **items** )
        """
        ...

    def setComboBoxItems(self, items: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#comboBoxItems-prop

        **comboBoxItems : QStringList**

        This property holds the items used in the combo box for the input dialog

        **Access functions:**

        QStringList **comboBoxItems** () const
        void **setComboBoxItems**
        (const QStringList & **items** )
        """
        ...

    def isComboBoxEditable(self) -> bool:
        ...

    def setComboBoxEditable(self, editable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#comboBoxEditable-prop

        **comboBoxEditable : bool**

        This property holds whether or not the combo box used in the input
        dialog is editable

        **Access functions:**

        bool **isComboBoxEditable** () const
        void **setComboBoxEditable**
        (bool **editable** )
        """
        ...

    def textEchoMode(self) -> "QLineEdit.EchoMode":
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textEchoMode-prop

        **textEchoMode : QLineEdit::EchoMode**

        This property holds the echo mode for the text value

        This property is only relevant when the input dialog is used in
        **TextInput**  mode.

        **Access functions:**

        QLineEdit::EchoMode **textEchoMode** () const
        void **setTextEchoMode**
        (QLineEdit::EchoMode **mode** )
        """
        ...

    def setTextEchoMode(self, mode: "QLineEdit.EchoMode") -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textEchoMode-prop

        **textEchoMode : QLineEdit::EchoMode**

        This property holds the echo mode for the text value

        This property is only relevant when the input dialog is used in
        **TextInput**  mode.

        **Access functions:**

        QLineEdit::EchoMode **textEchoMode** () const
        void **setTextEchoMode**
        (QLineEdit::EchoMode **mode** )
        """
        ...

    def textValue(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textValue-prop

        **textValue : QString**

        This property holds the text value for the input dialog

        This property is only relevant when the input dialog is used in
        **TextInput**  mode.

        **Access functions:**

        QString **textValue** () const
        void **setTextValue** (const QString &
        **text** )

        **Notifier signal:**

        void ****textValueChanged** ** (const QString & **text** )

        **Member Function Documentation**
        """
        ...

    def setTextValue(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textValue-prop

        **textValue : QString**

        This property holds the text value for the input dialog

        This property is only relevant when the input dialog is used in
        **TextInput**  mode.

        **Access functions:**

        QString **textValue** () const
        void **setTextValue** (const QString &
        **text** )

        **Notifier signal:**

        void ****textValueChanged** ** (const QString & **text** )

        **Member Function Documentation**
        """
        ...

    def options(self) -> "QInputDialog.InputDialogOption":
        """
        https://doc.qt.io/qt-6/qinputdialog.html#options-prop

        **options : InputDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        **Access functions:**

        QInputDialog::InputDialogOptions **options** () const
        void
        **setOptions** (QInputDialog::InputDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def setOptions(self, options: "QInputDialog.InputDialogOption") -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#options-prop

        **options : InputDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        **Access functions:**

        QInputDialog::InputDialogOptions **options** () const
        void
        **setOptions** (QInputDialog::InputDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def testOption(self, option: "QInputDialog.InputDialogOption") -> bool:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#testOption

        **bool QInputDialog::testOption(QInputDialog::InputDialogOption option )
        const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        **See also** **options**  and **setOption** ().
        """
        ...

    def setOption(
        self, option: "QInputDialog.InputDialogOption", on: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#setOption

        **void QInputDialog::setOption(QInputDialog::InputDialogOption option ,
        bool on = true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        **See also** **options**  and **testOption** ().
        """
        ...

    def labelText(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#labelText-prop

        **labelText : QString**

        This property holds the label's text which describes what needs to be
        input

        **Access functions:**

        QString **labelText** () const
        void **setLabelText** (const QString &
        **text** )
        """
        ...

    def setLabelText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#labelText-prop

        **labelText : QString**

        This property holds the label's text which describes what needs to be
        input

        **Access functions:**

        QString **labelText** () const
        void **setLabelText** (const QString &
        **text** )
        """
        ...

    def inputMode(self) -> "QInputDialog.InputMode":
        """
        https://doc.qt.io/qt-6/qinputdialog.html#inputMode-prop

        **inputMode : InputMode**

        This property holds the mode used for input

        This property helps determine which widget is used for entering input
        into the dialog.

        **Access functions:**

        QInputDialog::InputMode **inputMode** () const
        void **setInputMode**
        (QInputDialog::InputMode **mode** )
        """
        ...

    def setInputMode(self, mode: "QInputDialog.InputMode") -> None:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#inputMode-prop

        **inputMode : InputMode**

        This property holds the mode used for input

        This property helps determine which widget is used for entering input
        into the dialog.

        **Access functions:**

        QInputDialog::InputMode **inputMode** () const
        void **setInputMode**
        (QInputDialog::InputMode **mode** )
        """
        ...

    @staticmethod
    def getMultiLineText(
        parent: QWidget,
        title: str,
        label: str,
        text: str = ...,
        flags: QtCore.Qt.WindowType = ...,
        inputMethodHints: QtCore.Qt.InputMethodHint = ...,
    ) -> typing.Tuple[str, bool]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#getMultiLineText

        **[static, since 5.2] QString QInputDialog::getMultiLineText(QWidget *
        parent , const QString & title , const QString & label , const QString &
        text = QString(), bool * ok = nullptr, Qt::WindowFlags flags =
        Qt::WindowFlags(), Qt::InputMethodHints inputMethodHints =
        Qt::ImhNone)**

        Static convenience function to get a multiline string from the user.

        **title** is the text which is displayed in the title bar of the dialog.
        **label** is the text which is shown to the user (it should say what
        should be entered). **text** is the default text which is placed in the
        plain text edit. **inputMethodHints** is the input method hints that
        will be used in the edit widget if an input method is active.

        If **ok** is nonnull ***ok** will be set to true if the user pressed
        **OK** and to false if the user pressed **Cancel**. The dialog's parent
        is **parent**. The dialog will be modal and uses the specified widget
        **flags**.

        If the dialog is accepted, this function returns the text in the
        dialog's plain text edit. If the dialog is rejected, a null **QString**
        is returned.

        Use this static function like this:

        bool ok;
                **QString**  text = **QInputDialog**
        ::getMultiLineText(this, tr("QInputDialog::getMultiLineText()"),
        tr("Address:"), "John Doe\\nFreedom Street", &ok);
                if (ok &&
        !text.isEmpty())
                    multiLineTextLabel->setText(text);

        This function was introduced in Qt 5.2.

        **See also** **getInt** (), **getDouble** (), **getItem** (), and
        **getText** ().
        """
        ...

    @staticmethod
    def getItem(
        parent: QWidget,
        title: str,
        label: str,
        items: typing.Iterable[str],
        current: int = ...,
        editable: bool = ...,
        flags: QtCore.Qt.WindowType = ...,
        inputMethodHints: QtCore.Qt.InputMethodHint = ...,
    ) -> typing.Tuple[str, bool]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#getItem

        **[static] QString QInputDialog::getItem(QWidget * parent , const
        QString & title , const QString & label , const QStringList & items ,
        int current = 0, bool editable = true, bool * ok = nullptr,
        Qt::WindowFlags flags = Qt::WindowFlags(), Qt::InputMethodHints
        inputMethodHints = Qt::ImhNone)**

        Static convenience function to let the user select an item from a string
        list.

        **title** is the text which is displayed in the title bar of the dialog.
        **label** is the text which is shown to the user (it should say what
        should be entered). **items** is the string list which is inserted into
        the combo box. **current** is the number of the item which should be the
        current item. **inputMethodHints** is the input method hints that will
        be used if the combo box is editable and an input method is active.

        If **editable** is true the user can enter their own text; otherwise,
        the user may only select one of the existing items.

        If **ok** is nonnull ***ok** will be set to true if the user pressed
        **OK** and to false if the user pressed **Cancel**. The dialog's parent
        is **parent**. The dialog will be modal and uses the widget **flags**.

        This function returns the text of the current item, or if **editable**
        is true, the current text of the combo box.

        Use this static function like this:

        **QStringList**  items;
                items << tr("Spring") << tr("Summer") <<
        tr("Fall") << tr("Winter");

                bool ok;
                **QString**
        item = **QInputDialog** ::getItem(this, tr("QInputDialog::getItem()"),
        tr("Season:"), items, 0, false, &ok);
                if (ok && !item.isEmpty())
        itemLabel->setText(item);

        **See also** **getText** (), **getInt** (), **getDouble** (), and
        **getMultiLineText** ().
        """
        ...

    @staticmethod
    def getDouble(
        parent: QWidget,
        title: str,
        label: str,
        value: float = ...,
        min: float = ...,
        max: float = ...,
        decimals: int = ...,
        flags: QtCore.Qt.WindowType = ...,
        step: float = ...,
    ) -> typing.Tuple[float, bool]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#getDouble

        **[static] double QInputDialog::getDouble(QWidget * parent , const
        QString & title , const QString & label , double value = 0, double min =
        -2147483647, double max = 2147483647, int decimals = 1, bool * ok =
        nullptr, Qt::WindowFlags flags = Qt::WindowFlags(), double step = 1)**

        Static convenience function to get a floating point number from the
        user.

        **title** is the text which is displayed in the title bar of the dialog.
        **label** is the text which is shown to the user (it should say what
        should be entered). **value** is the default floating point number that
        the line edit will be set to. **min** and **max** are the minimum and
        maximum values the user may choose. **decimals** is the maximum number
        of decimal places the number may have. **step** is the amount by which
        the values change as the user presses the arrow buttons to increment or
        decrement the value.

        If **ok** is nonnull, * **ok** will be set to true if the user pressed
        **OK** and to false if the user pressed **Cancel**. The dialog's parent
        is **parent**. The dialog will be modal and uses the widget **flags**.

        This function returns the floating point number which has been entered
        by the user.

        Use this static function like this:

        bool ok;
                double d = **QInputDialog** ::getDouble(this,
        tr("QInputDialog::getDouble()"),
        tr("Amount:"), 37.56, -10000, 10000, 2, &ok,
        Qt::WindowFlags(), 1);
                if (ok)
        doubleLabel->setText(**QString** ("$%1").arg(d));

        **See also** **getText** (), **getInt** (), **getItem** (), and
        **getMultiLineText** ().
        """
        ...

    @staticmethod
    def getInt(
        parent: QWidget,
        title: str,
        label: str,
        value: int = ...,
        min: int = ...,
        max: int = ...,
        step: int = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#getInt

        **[static] int QInputDialog::getInt(QWidget * parent , const QString &
        title , const QString & label , int value = 0, int min = -2147483647,
        int max = 2147483647, int step = 1, bool * ok = nullptr, Qt::WindowFlags
        flags = Qt::WindowFlags())**

        Static convenience function to get an integer input from the user.

        **title** is the text which is displayed in the title bar of the dialog.
        **label** is the text which is shown to the user (it should say what
        should be entered). **value** is the default integer which the spinbox
        will be set to. **min** and **max** are the minimum and maximum values
        the user may choose. **step** is the amount by which the values change
        as the user presses the arrow buttons to increment or decrement the
        value.

        If **ok** is nonnull * **ok** will be set to true if the user pressed
        **OK** and to false if the user pressed **Cancel**. The dialog's parent
        is **parent**. The dialog will be modal and uses the widget **flags**.

        On success, this function returns the integer which has been entered by
        the user; on failure, it returns the initial **value**.

        Use this static function like this:

        bool ok;
                int i = **QInputDialog** ::getInt(this,
        tr("QInputDialog::getInt()"),
        tr("Percentage:"), 25, 0, 100, 1, &ok);
                if (ok)
        integerLabel->setText(tr("%1%").arg(i));

        **See also** **getText** (), **getDouble** (), **getItem** (), and
        **getMultiLineText** ().
        """
        ...

    @staticmethod
    def getText(
        parent: QWidget,
        title: str,
        label: str,
        echo: "QLineEdit.EchoMode" = ...,
        text: str = ...,
        flags: QtCore.Qt.WindowType = ...,
        inputMethodHints: QtCore.Qt.InputMethodHint = ...,
    ) -> typing.Tuple[str, bool]:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#getText

        **[static] QString QInputDialog::getText(QWidget * parent , const
        QString & title , const QString & label , QLineEdit::EchoMode mode =
        QLineEdit::Normal, const QString & text = QString(), bool * ok =
        nullptr, Qt::WindowFlags flags = Qt::WindowFlags(), Qt::InputMethodHints
        inputMethodHints = Qt::ImhNone)**

        Static convenience function to get a string from the user.

        **title** is the text which is displayed in the title bar of the dialog.
        **label** is the text which is shown to the user (it should say what
        should be entered). **text** is the default text which is placed in the
        line edit. **mode** is the echo mode the line edit will use.
        **inputMethodHints** is the input method hints that will be used in the
        edit widget if an input method is active.

        If **ok** is nonnull ***ok** will be set to true if the user pressed
        **OK** and to false if the user pressed **Cancel**. The dialog's parent
        is **parent**. The dialog will be modal and uses the specified widget
        **flags**.

        If the dialog is accepted, this function returns the text in the
        dialog's line edit. If the dialog is rejected, a null **QString**  is
        returned.

        Use this static function like this:

        bool ok;
                **QString**  text = **QInputDialog** ::getText(this,
        tr("QInputDialog::getText()"),
        tr("User name:"), **QLineEdit** ::Normal,
        **QDir** ::home().dirName(), &ok);
                if (ok && !text.isEmpty())
        textLabel->setText(text);

        **See also** **getInt** (), **getDouble** (), **getItem** (), and
        **getMultiLineText** ().
        """
        ...

    @property
    def doubleValueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleValueChanged

        **[signal] void QInputDialog::doubleValueChanged(double value )**

        This signal is emitted whenever the double value changes in the dialog.
        The current value is specified by **value**.

        This signal is only relevant when the input dialog is used in
        **DoubleInput**  mode.

        **Note:** Notifier signal for property **doubleValue** .
        """
        ...

    @property
    def doubleValueSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#doubleValueSelected

        **[signal] void QInputDialog::doubleValueSelected(double value )**

        This signal is emitted whenever the user selects a double value by
        accepting the dialog; for example, by clicking the **OK** button. The
        selected value is specified by **value**.

        This signal is only relevant when the input dialog is used in
        **DoubleInput**  mode.
        """
        ...

    @property
    def intValueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intValueChanged

        **[signal] void QInputDialog::intValueChanged(int value )**

        This signal is emitted whenever the integer value changes in the dialog.
        The current value is specified by **value**.

        This signal is only relevant when the input dialog is used in
        **IntInput**  mode.

        **Note:** Notifier signal for property **intValue** .
        """
        ...

    @property
    def intValueSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#intValueSelected

        **[signal] void QInputDialog::intValueSelected(int value )**

        This signal is emitted whenever the user selects a integer value by
        accepting the dialog; for example, by clicking the **OK** button. The
        selected value is specified by **value**.

        This signal is only relevant when the input dialog is used in
        **IntInput**  mode.
        """
        ...

    @property
    def textValueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textValueChanged

        **[signal] void QInputDialog::textValueChanged(const QString & text )**

        This signal is emitted whenever the text string changes in the dialog.
        The current string is specified by **text**.

        This signal is only relevant when the input dialog is used in
        **TextInput**  mode.

        **Note:** Notifier signal for property **textValue** .
        """
        ...

    @property
    def textValueSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qinputdialog.html#textValueSelected

        **[signal] void QInputDialog::textValueSelected(const QString & text )**

        This signal is emitted whenever the user selects a text string by
        accepting the dialog; for example, by clicking the **OK** button. The
        selected string is specified by **text**.

        This signal is only relevant when the input dialog is used in
        **TextInput**  mode.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QKeyCombination(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qkeycombination.html

    **Detailed Description**

    The QKeyCombination class can be used to represent a combination of a key
    with zero or more keyboard modifiers.

    **See also** **QKeySequence** .
    """

    @typing.overload
    def __init__(self, key: Qt.Key = ...) -> None:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#QKeyCombination

        **QKeyCombination::QKeyCombination(Qt::Key key = Qt::Key_unknown)**

        Constructs a QKeyCombination object that represents the key **key** and
        no modifiers.

        **See also** **key** ().
        """
        ...

    @typing.overload
    def __init__(self, modifiers: Qt.Modifier, key: Qt.Key = ...) -> None:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#QKeyCombination-1

        **QKeyCombination::QKeyCombination(Qt::Modifiers modifiers , Qt::Key key
        = Qt::Key_unknown)**

        Constructs a QKeyCombination object that represents the combination of
        **key** with the modifiers **modifiers**.

        **See also** **key** () and **keyboardModifiers** ().
        """
        ...

    @typing.overload
    def __init__(self, modifiers: Qt.KeyboardModifier, key: Qt.Key = ...) -> None:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#QKeyCombination-2

        **QKeyCombination::QKeyCombination(Qt::KeyboardModifiers modifiers ,
        Qt::Key key = Qt::Key_unknown)**

        Constructs a QKeyCombination object that represents the combination of
        **key** with the modifiers **modifiers**.

        **See also** **key** () and **keyboardModifiers** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QKeyCombination") -> None:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#QKeyCombination

        **QKeyCombination::QKeyCombination(Qt::Key key = Qt::Key_unknown)**

        Constructs a QKeyCombination object that represents the key **key** and
        no modifiers.

        **See also** **key** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def toCombined(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#toCombined

        **int QKeyCombination::toCombined() const**

        Returns an integer value obtained by applying a bitwise OR between the
        values of **key** () and **keyboardModifiers** () represented by this
        object. A **QKeyCombination**  object can be created from the returned
        integer value by using **fromCombined** ().

        **See also** **fromCombined** (), **key** (), and **keyboardModifiers**
        ().
        """
        ...

    @staticmethod
    def fromCombined(combined: int) -> "QKeyCombination":
        """
        https://doc.qt.io/qt-6/qkeycombination.html#fromCombined

        **[static] QKeyCombination QKeyCombination::fromCombined(int combined
        )**

        Constructs a **QKeyCombination**  object by extracting the key and the
        modifiers out of **combined** , which must be the result of a bitwise OR
        between a value of type **Qt::Key**  and value of type
        **Qt::KeyboardModifiers** . **toCombined** () can be used in order to
        produce valid values for **combined**.

        **See also** **toCombined** ().
        """
        ...

    def key(self) -> Qt.Key:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#key

        **Qt::Key QKeyCombination::key() const**

        Returns the key represented by this **QKeyCombination**  object.

        **See also** **keyboardModifiers** ().
        """
        ...

    def keyboardModifiers(self) -> Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qkeycombination.html#keyboardModifiers

        **Qt::KeyboardModifiers QKeyCombination::keyboardModifiers() const**

        Returns the keyboard modifiers represented by this **QKeyCombination**
        object.

        **See also** **key** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QLineF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlinef.html

    **Detailed Description**

    A QLineF describes a finite length line (or line segment) on a two-
    dimensional surface. QLineF defines the start and end points of the line
    using floating point accuracy for coordinates. Use the **toLine** ()
    function to retrieve an integer-based copy of this line.

    ![](images/qline-point.png)![](images/qline-coordinates.png)

    The positions of the line's start and end points can be retrieved using the
    **p1** (), **x1** (), **y1** (), **p2** (), **x2** (), and **y2** ()
    functions. The **dx** () and **dy** () functions return the horizontal and
    vertical components of the line, respectively.

    The line's length can be retrieved using the **length** () function, and
    altered using the **setLength** () function. Similarly, **angle** () and
    **setAngle** () are respectively used for retrieving and altering the angle
    of the line. Use the **isNull** () function to determine whether the QLineF
    represents a valid line or a null line.

    The **intersects** () function determines the **IntersectionType**  for this
    line and a given line, while the **angleTo** () function returns the angle
    between the lines. In addition, the **unitVector** () function returns a
    line that has the same starting point as this line, but with a length of
    only 1, while the **normalVector** () function returns a line that is
    perpendicular to this line with the same starting point and length.

    Finally, the line can be translated a given offset using the **translate**
    () function, and can be traversed using the **pointAt** () function.

    **Constraints**

    **QLine**  is limited to the minimum and maximum values for the `int` type.
    Operations on a **QLine**  that could potentially result in values outside
    this range will result in undefined behavior.

    **See also** **QLine** , **QPolygonF** , and **QRectF** .
    """

    class IntersectionType(enum.Enum):
        NoIntersection: QLineF = ...
        BoundedIntersection: QLineF = ...
        UnboundedIntersection: QLineF = ...

    @typing.overload
    def __init__(self, line: QLine) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#QLineF

        **QLineF::QLineF()**

        Constructs a null line.
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#QLineF-1

        **QLineF::QLineF(const QPointF & p1 , const QPointF & p2 )**

        Constructs a line object that represents the line between **p1** and
        **p2**.
        """
        ...

    @typing.overload
    def __init__(self, apt1: "QPointF", apt2: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#QLineF-2

        **QLineF::QLineF(qreal x1 , qreal y1 , qreal x2 , qreal y2 )**

        Constructs a line object that represents the line between ( **x1** ,
        **y1** ) and ( **x2** , **y2** ).
        """
        ...

    @typing.overload
    def __init__(self, x1pos: float, y1pos: float, x2pos: float, y2pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#QLineF-3

        **QLineF::QLineF(const QLine & line )**

        Construct a QLineF object from the given integer-based **line**.

        **See also** **toLine** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QLineF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#QLineF

        **QLineF::QLineF()**

        Constructs a null line.
        """
        ...

    def center(self) -> "QPointF":
        """
        https://doc.qt.io/qt-6/qlinef.html#center

        **[since 5.8] QPointF QLineF::center() const**

        Returns the center point of this line. This is equivalent to 0.5 *
        **p1** () + 0.5 * **p2** ().

        This function was introduced in Qt 5.8.
        """
        ...

    def setLine(self, aX1: float, aY1: float, aX2: float, aY2: float) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setLine

        **void QLineF::setLine(qreal x1 , qreal y1 , qreal x2 , qreal y2 )**

        Sets this line to the start in **x1** , **y1** and end in **x2** ,
        **y2**.

        **See also** **setP1** (), **setP2** (), **p1** (), and **p2** ().
        """
        ...

    def setPoints(self, aP1: "QPointF", aP2: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setPoints

        **void QLineF::setPoints(const QPointF & p1 , const QPointF & p2 )**

        Sets the start point of this line to **p1** and the end point of this
        line to **p2**.

        **See also** **setP1** (), **setP2** (), **p1** (), and **p2** ().
        """
        ...

    def setP2(self, aP2: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setP2

        **void QLineF::setP2(const QPointF & p2 )**

        Sets the end point of this line to **p2**.

        **See also** **setP1** () and **p2** ().
        """
        ...

    def setP1(self, aP1: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setP1

        **void QLineF::setP1(const QPointF & p1 )**

        Sets the starting point of this line to **p1**.

        **See also** **setP2** () and **p1** ().
        """
        ...

    @typing.overload
    def translated(self, p: "QPointF") -> "QLineF":
        """
        https://doc.qt.io/qt-6/qlinef.html#translated

        **QLineF QLineF::translated(const QPointF & offset ) const**

        Returns this line translated by the given **offset**.
        """
        ...

    @typing.overload
    def translated(self, adx: float, ady: float) -> "QLineF":
        """
        https://doc.qt.io/qt-6/qlinef.html#translated-1

        **QLineF QLineF::translated(qreal dx , qreal dy ) const**

        This is an overloaded function.

        Returns this line translated the distance specified by **dx** and
        **dy**.
        """
        ...

    def angleTo(self, l: "QLineF") -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#angleTo

        **qreal QLineF::angleTo(const QLineF & line ) const**

        Returns the angle (in degrees) from this line to the given **line** ,
        taking the direction of the lines into account. If the lines do not
        **intersect**  within their range, it is the intersection point of the
        extended lines that serves as origin (see
        **QLineF::UnboundedIntersection** ).

        The returned value represents the number of degrees you need to add to
        this line to make it have the same angle as the given **line** , going
        counter-clockwise.

        **See also** **intersects** ().
        """
        ...

    def setAngle(self, angle: float) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setAngle

        **void QLineF::setAngle(qreal angle )**

        Sets the angle of the line to the given **angle** (in degrees). This
        will change the position of the second point of the line such that the
        line has the given angle.

        Positive values for the angles mean counter-clockwise while negative
        values mean the clockwise direction. Zero degrees is at the 3 o'clock
        position.

        **See also** **angle** ().
        """
        ...

    def angle(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#angle

        **qreal QLineF::angle() const**

        Returns the angle of the line in degrees.

        The return value will be in the range of values from 0.0 up to but not
        including 360.0. The angles are measured counter-clockwise from a point
        on the x-axis to the right of the origin (x > 0).

        **See also** **setAngle** ().
        """
        ...

    @staticmethod
    def fromPolar(length: float, angle: float) -> "QLineF":
        """
        https://doc.qt.io/qt-6/qlinef.html#fromPolar

        **[static] QLineF QLineF::fromPolar(qreal length , qreal angle )**

        Returns a **QLineF**  with the given **length** and **angle**.

        The first point of the line will be on the origin.

        Positive values for the angles mean counter-clockwise while negative
        values mean the clockwise direction. Zero degrees is at the 3 o'clock
        position.
        """
        ...

    def toLine(self) -> QLine:
        """
        https://doc.qt.io/qt-6/qlinef.html#toLine

        **QLine QLineF::toLine() const**

        Returns an integer-based copy of this line.

        Note that the returned line's start and end points are rounded to the
        nearest integer.

        **See also** **QLineF** ().
        """
        ...

    def pointAt(self, t: float) -> "QPointF":
        """
        https://doc.qt.io/qt-6/qlinef.html#pointAt

        **QPointF QLineF::pointAt(qreal t ) const**

        Returns the point at the position specified by finite parameter **t**.
        The function returns the line's start point if t = 0, and its end point
        if t = 1.

        **See also** **dx** () and **dy** ().
        """
        ...

    def setLength(self, len: float) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#setLength

        **void QLineF::setLength(qreal length )**

        Sets the length of the line to the given finite **length**. **QLineF**
        will move the end point - **p2** () - of the line to give the line its
        new length, unless **length** () was previously zero, in which case no
        scaling is attempted.

        **See also** **length** () and **unitVector** ().
        """
        ...

    @typing.overload
    def translate(self, point: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#translate

        **void QLineF::translate(const QPointF & offset )**

        Translates this line by the given **offset**.
        """
        ...

    @typing.overload
    def translate(self, adx: float, ady: float) -> None:
        """
        https://doc.qt.io/qt-6/qlinef.html#translate-1

        **void QLineF::translate(qreal dx , qreal dy )**

        This is an overloaded function.

        Translates this line the distance specified by **dx** and **dy**.
        """
        ...

    def normalVector(self) -> "QLineF":
        """
        https://doc.qt.io/qt-6/qlinef.html#normalVector

        **QLineF QLineF::normalVector() const**

        Returns a line that is perpendicular to this line with the same starting
        point and length.

        ![](images/qlinef-normalvector.png)

        **See also** **unitVector** ().
        """
        ...

    def dy(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#dy

        **qreal QLineF::dy() const**

        Returns the vertical component of the line's vector.

        **See also** **dx** () and **pointAt** ().
        """
        ...

    def dx(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#dx

        **qreal QLineF::dx() const**

        Returns the horizontal component of the line's vector.

        **See also** **dy** () and **pointAt** ().
        """
        ...

    def p2(self) -> "QPointF":
        """
        https://doc.qt.io/qt-6/qlinef.html#p2

        **QPointF QLineF::p2() const**

        Returns the line's end point.

        **See also** **setP2** (), **x2** (), **y2** (), and **p1** ().
        """
        ...

    def p1(self) -> "QPointF":
        """
        https://doc.qt.io/qt-6/qlinef.html#p1

        **QPointF QLineF::p1() const**

        Returns the line's start point.

        **See also** **setP1** (), **x1** (), **y1** (), and **p2** ().
        """
        ...

    def y2(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#y2

        **qreal QLineF::y2() const**

        Returns the y-coordinate of the line's end point.

        **See also** **p2** ().
        """
        ...

    def x2(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#x2

        **qreal QLineF::x2() const**

        Returns the x-coordinate of the line's end point.

        **See also** **p2** ().
        """
        ...

    def y1(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#y1

        **qreal QLineF::y1() const**

        Returns the y-coordinate of the line's start point.

        **See also** **p1** ().
        """
        ...

    def x1(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#x1

        **qreal QLineF::x1() const**

        Returns the x-coordinate of the line's start point.

        **See also** **p1** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    def intersects(
        self, l: "QLineF"
    ) -> typing.Tuple["QLineF.IntersectionType", "QPointF"]:
        """
        https://doc.qt.io/qt-6/qlinef.html#intersects

        **[since 5.14] QLineF::IntersectionType QLineF::intersects(const QLineF
        & line , QPointF * intersectionPoint = nullptr) const**

        Returns a value indicating whether or not **this** line intersects with
        the given **line**.

        The actual intersection point is extracted to **intersectionPoint** (if
        the pointer is valid). If the lines are parallel, the intersection point
        is undefined.

        This function was introduced in Qt 5.14.
        """
        ...

    def unitVector(self) -> "QLineF":
        """
        https://doc.qt.io/qt-6/qlinef.html#unitVector

        **QLineF QLineF::unitVector() const**

        Returns the unit vector for this line, i.e a line starting at the same
        point as **this** line with a length of 1.0, provided the line is non-
        null.

        **See also** **normalVector** () and **setLength** ().
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qlinef.html#length

        **qreal QLineF::length() const**

        Returns the length of the line.

        **See also** **setLength** () and **isNull** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlinef.html#isNull

        **bool QLineF::isNull() const**

        Returns `true` if the line does not have distinct start and end points;
        otherwise returns `false`. The start and end points are considered
        distinct if **qFuzzyCompare** () can distinguish them in at least one
        coordinate.

        **Note:** Due to the use of fuzzy comparison, isNull() may return `true`
        for lines whose **length** () is not zero.

        **See also** **qFuzzyCompare** () and **length** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QRunnable(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qrunnable.html

    **Detailed Description**

    The QRunnable class is an interface for representing a task or piece of code
    that needs to be executed, represented by your reimplementation of the
    **run** () function.

    You can use **QThreadPool**  to execute your code in a separate thread.
    **QThreadPool**  deletes the QRunnable automatically if **autoDelete** ()
    returns `true` (the default). Use **setAutoDelete** () to change the auto-
    deletion flag.

    **QThreadPool**  supports executing the same QRunnable more than once by
    calling **QThreadPool::tryStart** (this) from within the **run** ()
    function. If **autoDelete**  is enabled the QRunnable will be deleted when
    the last thread exits the run function. Calling **QThreadPool::start** ()
    multiple times with the same QRunnable when **autoDelete**  is enabled
    creates a race condition and is not recommended.

    **See also** **QThreadPool** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qrunnable.html#QRunnable-1

        **QRunnable::QRunnable()**

        Constructs a QRunnable. Auto-deletion is enabled by default.

        **See also** **autoDelete** () and **setAutoDelete** ().
        """
        ...

    @staticmethod
    def create(functionToRun: typing.Callable[[], None]) -> "QRunnable":
        """
        https://doc.qt.io/qt-6/qrunnable.html#create

        **[static, since 5.15] QRunnable *QRunnable::create(std::function<void
        ()> functionToRun )**

        Creates a **QRunnable**  that calls **functionToRun** in **run** ().

        Auto-deletion is enabled by default.

        This function was introduced in Qt 5.15.

        **See also** **run** () and **autoDelete** ().
        """
        ...

    def setAutoDelete(self, _autoDelete: bool) -> None:
        """
        https://doc.qt.io/qt-6/qrunnable.html#setAutoDelete

        **void QRunnable::setAutoDelete(bool autoDelete )**

        Enables auto-deletion if **autoDelete** is true; otherwise auto-deletion
        is disabled.

        If auto-deletion is enabled, **QThreadPool**  will automatically delete
        this runnable after calling **run** (); otherwise, ownership remains
        with the application programmer.

        Note that this flag must be set before calling **QThreadPool::start**
        (). Calling this function after **QThreadPool::start** () results in
        undefined behavior.

        **See also** **autoDelete** () and **QThreadPool** .
        """
        ...

    def autoDelete(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrunnable.html#autoDelete

        **bool QRunnable::autoDelete() const**

        Returns `true` is auto-deletion is enabled; false otherwise.

        If auto-deletion is enabled, **QThreadPool**  will automatically delete
        this runnable after calling **run** (); otherwise, ownership remains
        with the application programmer.

        **See also** **setAutoDelete** () and **QThreadPool** .
        """
        ...

    def run(self) -> None:
        """
        https://doc.qt.io/qt-6/qrunnable.html#run

        **[pure virtual] void QRunnable::run()**

        Implement this pure virtual function in your subclass.
        """
        ...
